import { BehaviorSubject } from 'rxjs';
import { HttpErrorResponse } from '@angular/common/http';
import { DataSourceCache } from '../data-source/cache/data-source-cache';
export declare const TIMEOUT_ERROR_MESSAGE = "TIMEOUT_ERROR";
export interface ApiDataSourceBase<REQUEST_MODEL, DATA> {
    readonly loading$: BehaviorSubject<boolean>;
    readonly result$: BehaviorSubject<DATA>;
    readonly error$: BehaviorSubject<HttpErrorResponse>;
    readonly loading: boolean;
    readonly result: DATA;
    readonly error: HttpErrorResponse;
    request(model?: REQUEST_MODEL, options?: ApiDataSourceRequestOptions<DATA>): void;
}
export declare enum ApiDataSourceCachingStrategy {
    Memory = 0,
    LocalStorage = 1,
    SessionStorage = 2
}
export interface ApiDataSourceCachingOptions {
    strategy?: ApiDataSourceCachingStrategy;
    /**
     * Expiration time in minutes
     */
    expiration: number;
}
export interface ApiDataSourceOptions<RESPONSE_MODEL, DATA, REQUEST_MODEL> {
    name?: string;
    initialResult?: DATA;
    timeout?: number;
    retry?: number;
    cache?: ApiDataSourceCachingOptions;
    map?: (response: RESPONSE_MODEL, request: REQUEST_MODEL) => DATA;
    initialValues?: {
        loading?: boolean;
        result?: DATA;
        error?: HttpErrorResponse;
    };
}
export interface ApiDataSourceRequestOptions<DATA, ERROR = Error> {
    success?: (mappedResponse?: DATA) => void;
    error?: (error: ERROR) => void;
    timeout?: number;
}
export interface ApiDataSourceInitialValues<DATA> {
    loading: boolean;
    result: DATA;
    error: HttpErrorResponse;
}
export declare class ApiDataSource<REQUEST_MODEL, DATA, RESPONSE_MODEL = unknown, SERVICE = unknown, K extends keyof SERVICE = keyof SERVICE> implements ApiDataSourceBase<REQUEST_MODEL, DATA> {
    service: SERVICE;
    readonly methodName: K;
    private readonly options?;
    /**
     * Indicates whether the request is initiated and in progress.
     */
    get loading$(): BehaviorSubject<boolean>;
    get loading(): boolean;
    protected readonly _loading$: BehaviorSubject<boolean>;
    /**
     * Stream of request results. Conditionally mapped if a mapping function is provided.
     */
    get result$(): BehaviorSubject<DATA>;
    get result(): DATA;
    protected readonly _result$: BehaviorSubject<DATA>;
    /**
     * Stream of errors.
     */
    get error$(): BehaviorSubject<HttpErrorResponse>;
    get error(): HttpErrorResponse;
    protected readonly _error$: BehaviorSubject<HttpErrorResponse>;
    get lastRequestModel(): REQUEST_MODEL;
    protected _lastRequestModel?: REQUEST_MODEL;
    /**
     * Datasource name. Used for example by the ApiDataProxy to select the current ApiDataSource.
     */
    readonly name: string;
    /**
     * Defines the amount of time after which the request times out.
     */
    timeout: number;
    /**
     * Defines the amount of times the request should be retried before failing.
     */
    retry: number;
    /**
     * Mapping function used to transform the RESPONSE_MODEL to DATA.
     */
    private readonly mappingFn;
    private requestSubscription;
    protected cache: DataSourceCache<REQUEST_MODEL, RESPONSE_MODEL>;
    /**
     * Default initial values used for the exposed observables.
     */
    protected defaultInitialValues: ApiDataSourceInitialValues<DATA>;
    protected lastRequestOptions?: ApiDataSourceRequestOptions<DATA>;
    constructor(service: SERVICE, methodName: K, options?: ApiDataSourceOptions<RESPONSE_MODEL, DATA, REQUEST_MODEL>);
    request(model?: REQUEST_MODEL, options?: ApiDataSourceRequestOptions<DATA>): void;
    requestPromise(model?: REQUEST_MODEL): Promise<DATA>;
    cancel(): void;
    retryRequest(): void;
    clearCache(): void;
    private writeToCache;
    private respondFromCache;
    protected getInitialValues(): ApiDataSourceInitialValues<DATA>;
    protected onSuccess(response: RESPONSE_MODEL, requestModel?: REQUEST_MODEL, successCallback?: (mappedResponse: DATA) => void): void;
    protected onError(error: HttpErrorResponse, errorCallback?: (error: Error) => void): void;
    protected mapResponse(response: RESPONSE_MODEL, request?: REQUEST_MODEL): DATA;
    private getRequestPipes;
    private setUpCaching;
}
//# sourceMappingURL=api-data-source.d.ts.map