import { ApiDataSource, ApiDataSourceOptions, ApiDataSourceRequestOptions } from './api-data-source';
import { BehaviorSubject } from 'rxjs';
import { InfiniteListPagination } from '../pagination/infinite-list-pagination';
import { PaginationOptions } from '../pagination/base-list-pagination';
import { PlainObject } from '../types';
export declare enum ApiInfiniteListDataSourceOffsetStrategy {
    Index = 0,
    Page = 1
}
export interface ApiInfiniteListDataSourceOptions<RESPONSE_MODEL, DATA, REQUEST_MODEL> extends ApiDataSourceOptions<RESPONSE_MODEL, DATA, REQUEST_MODEL> {
    pagination?: PaginationOptions;
    offsetStrategy?: ApiInfiniteListDataSourceOffsetStrategy;
    offsetKey?: string;
    limitKey?: string;
    paginationInstance?: InfiniteListPagination;
}
export declare class ApiInfiniteListDataSource<REQUEST_MODEL, DATA, RESPONSE_MODEL extends {
    count?: number;
}, SERVICE = unknown, K extends keyof SERVICE = keyof SERVICE> extends ApiDataSource<REQUEST_MODEL, DATA[], RESPONSE_MODEL, SERVICE> {
    /**
     * Overriding original result$ to be able to merge old and new results.
     */
    get result$(): BehaviorSubject<DATA[]>;
    protected _listResult: BehaviorSubject<DATA[]>;
    /**
     * Indicates whether the list is loaded initially.
     */
    get loading$(): BehaviorSubject<boolean>;
    protected initiallyLoading$: BehaviorSubject<boolean>;
    protected initialLoad$: BehaviorSubject<boolean>;
    /**
     * Indicates whether more items are loaded.
     */
    loadingMore$: BehaviorSubject<boolean>;
    allItemsLoaded$: BehaviorSubject<boolean>;
    loadMoreError$: import("rxjs").Observable<import("@angular/common/http").HttpErrorResponse>;
    readonly pagination: InfiniteListPagination;
    protected readonly offsetKey: string;
    protected readonly limitKey: string;
    constructor(service: SERVICE, methodName: K, options?: ApiInfiniteListDataSourceOptions<RESPONSE_MODEL, DATA[], REQUEST_MODEL>);
    request(model?: REQUEST_MODEL, options?: ApiDataSourceRequestOptions<DATA[]>): void;
    requestMore(model?: REQUEST_MODEL, options?: ApiDataSourceRequestOptions<DATA[]>): void;
    requestAll(model?: REQUEST_MODEL): Promise<void>;
    cancel(): void;
    cancelAndResetList(): void;
    restoreFromCache(data: DATA[], pagination: {
        totalEntries: number;
        activePage: number;
    }): void;
    private doRequest;
    protected mapResponse(response: RESPONSE_MODEL, request?: REQUEST_MODEL): DATA[];
    protected getPaginationParameters(): PlainObject<number>;
    private updateActivePage;
}
//# sourceMappingURL=api-infinite-list-data-source.d.ts.map