import { KeyOfType } from '../types/key-of-type';
export declare class ArrayUtil {
    static is<T = unknown>(array: T[]): ArrayComparator<T>;
    static mapToStrings(array: number[]): string[];
    static fromEnum<T = unknown>(enumm: unknown): T[];
    static generate<T = unknown>(length: number, mapFn?: (index: number) => unknown): T[];
    static last<T>(array: T[]): T | undefined;
    static lastIndex(array: unknown[]): number;
    static moveToIndex<A = string>(array: A[], newIndex: number, compareFn: (element: A, index: number, array: A[]) => boolean): boolean;
    static getPriorityBasedOnKey(array: unknown[], key: string): number;
    static findByAttribute<T>(array: T[], field: keyof T, value: unknown): T | undefined;
    static wrapElementOrNull<T>(value: T): T[] | null;
    static replaceOrAddWithSameKey<T, K extends keyof T>(array: T[], field: K, element: T, expectedKey: T[K]): void;
    static limit<T>(array: T[], limit: number): T[];
    static defaultIfEmpty<T>(array: T[], fallback: T[]): T[];
}
export declare class ArrayComparator<T> {
    private readonly array;
    constructor(array: T[]);
    /**
     * Comparator function which checks if the given array items have the same order as in the array it's compared against.
     * The function ignores missing and additional items. If items that are within both arrays are in the same order it will yield `true`.
     *
     * @example
     * // returns true
     * ArrayUtil.is([1,2,3]).ofSameItemOrderAs([1,2,3,4,5]);
     *
     * // returns false
     * ArrayUtil.is([1,3,2]).ofSameItemOrderAs([1,2,3,4,5]);
     */
    ofSameItemOrderAs(compareArray: T[]): boolean;
    containingAllItemsOf(compareArray: T[]): boolean;
}
interface IdItem {
    id?: string | null;
}
interface KeyItem {
    key?: string | null;
}
/**
 * Get an item by ID from an arbitrary array where the items contain an `id` field
 *
 * @param array Array of items which have at least `id` field
 * @param id Id to be matched
 * @return Item found or `undefined`
 */
export declare const getItemForId: <T extends IdItem>(array: T[], id: string) => T;
export declare const sortArrayWithPriority: <T = string, P = string>(array: T[], priorities: P[], sortByPropPath?: string) => T[];
export declare const sortArrayBasedOnKey: <T extends KeyItem>(priority: unknown[], result: T[]) => T[];
export declare const sortArrayByParameter: <T>(result: T[], p: keyof { [P in keyof T as T[P] extends number ? P : never]: any; }) => T[];
export {};
//# sourceMappingURL=array.util.d.ts.map