import { MapperFn, RequestMethod } from './types';
export declare enum DataSourceCachingStrategy {
    Memory = 0,
    LocalStorage = 1,
    SessionStorage = 2
}
export interface DataSourceCacheOptions {
    strategy?: DataSourceCachingStrategy;
    expiration: number;
}
/**
 * @typeParam R - Type of the response.
 * @typeParam D - Type of the data the DataSource provides.
 * @typeParam RM - Type of the model used to request data. Defaults to `void`.
 */
export interface DataSourceOptions<R, D, RM = void> {
    /**
     * Unique name of the data source.
     */
    name?: string;
    /**
     * Request function returning the data.
     */
    request: RequestMethod<RM, R>;
    /**
     * Mapper function that transforms the request data to the DataSources data model.
     */
    map?: MapperFn<R, D>;
    /**
     * Defines after what amount of time the request should be canceled if no response is given.
     */
    timeout?: number;
    /**
     * Number of times the request should be retried if it yields an error.
     */
    retry?: number;
    /**
     * Caching options. Define the caching strategy and expiration.
     */
    cache?: DataSourceCacheOptions;
    /**
     * Initial DataSource values exposed.
     */
    initial?: {
        loading?: boolean;
        data?: D;
        error?: Error;
    };
}
export interface MappableDataSourceFactoryOptions<R, D, RM> extends DataSourceOptions<R, D, RM> {
    request: RequestMethod<RM, R>;
    map: MapperFn<R, D>;
}
export interface DataSourceFactoryOptions<R, RM> extends DataSourceOptions<R, R, RM> {
    request: RequestMethod<RM, R>;
}
//# sourceMappingURL=data-source-options.d.ts.map