export declare const CACHE_KEY_PREFIX = "sieportal.cache";
export interface DataCacheRecord<DATA> {
    expiration: number;
    data: DATA;
}
export interface DataCache<DATA, KEY> {
    readonly id: string;
    readonly expiration: number;
    readonly expirationMs: number;
    readonly size: number;
    get(key: KEY): DataCacheRecord<DATA> | undefined;
    set(key: KEY, data: DATA): void;
    upsert(key: KEY, data: Partial<DATA>): void;
    has(key: KEY): boolean;
    delete(key: KEY): boolean;
    clear(): void;
    expired(key: KEY): boolean;
}
export declare function getCacheId(id: string): string;
export declare abstract class AbstractDataCache<DATA, KEY = string> implements DataCache<DATA, KEY> {
    readonly id: string;
    readonly expiration: number;
    /**
     * Time after the data expires in milliseconds.
     */
    readonly expirationMs: number;
    /**
     * Number of cached entries.
     */
    get size(): number;
    /**
     * Object holding the cached values.
     */
    protected abstract cache: Map<KEY, DataCacheRecord<DATA>>;
    /**
     * @param id Unique identifier for the instance.
     * @param expirationInMinutes Expiration time in minutes.
     */
    constructor(id: string, expirationInMinutes: number, contextAware?: boolean);
    get(key: KEY): DataCacheRecord<DATA> | undefined;
    set(key: KEY, data: DATA): void;
    /**
     * This function will update an existing entry and prolong the expiration time.
     * In case of an expired entry no previous data will be lost.
     *
     * @param key the cache key
     * @param data the delta change which will be appended to the existing data
     */
    upsert(key: KEY, data: Partial<DATA>): void;
    has(key: KEY): boolean;
    delete(key: KEY): boolean;
    clear(): void;
    expired(key: KEY): boolean;
    protected getExpirationTime(): number;
    protected cacheRecordExpired(record: DataCacheRecord<DATA>): boolean;
}
//# sourceMappingURL=data-cache.d.ts.map