import { AfterContentInit, ElementRef, OnChanges } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * # Highlight Directive
 *
 * Directive is meant to be used on the elements that we want to highlight through, e.g. search suggestions.
 * It needs a reference, such as a search term, in order to highlight it in the suggestions.
 *
 * ## Code example
 * @example
 * Template:
 * ```html
 * <span
 *  sieCoreHighlight
 *  [reference]="searchTermToHighlight"
 *  [highlightStartOnly]="false"
 *  [highlightBackgroundColor]="true"
 *  >{{ searchSuggestionText }}
 * </span>
 * ```
 */
export declare class HighlightDirective implements AfterContentInit, OnChanges {
    private readonly el;
    /**
     * Reference is a string that is being highlighted on the elements the directive is being used on
     */
    reference: string;
    /**
     * If false the referenced string will be bold.
     */
    inverted: boolean;
    /**
     * Whether to highlight only matches at the start of the string or anywhere.
     */
    highlightStartOnly: boolean;
    /**
     * Whether also show highlight background color
     */
    highlightBackgroundColor: boolean;
    /** @ignore */
    highlightedText: string;
    private active;
    private originalText;
    constructor(el: ElementRef);
    private static escapeRegex;
    /** @ignore */
    ngOnChanges(): void;
    /** @ignore */
    ngAfterContentInit(): void;
    private highlight;
    private highlightText;
    private getHighlightString;
    static ɵfac: i0.ɵɵFactoryDeclaration<HighlightDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<HighlightDirective, "[sieCoreHighlight]", never, { "reference": { "alias": "reference"; "required": false; }; "inverted": { "alias": "inverted"; "required": false; }; "highlightStartOnly": { "alias": "highlightStartOnly"; "required": false; }; "highlightBackgroundColor": { "alias": "highlightBackgroundColor"; "required": false; }; }, {}, never, never, false, never>;
}
//# sourceMappingURL=highlight.directive.d.ts.map