import { UrlService } from '../../services/url.service';
import { RegionNotSupportedError } from '../../errors';
import { Region } from '../region/region';
import { LocaleConfigLoaderService } from './locale-config-loader.service';
import { BehaviorSubject } from 'rxjs';
import { LocaleString, PlainObject } from '../../types';
import { RegionTranslations } from '../region/region-translations';
import * as i0 from "@angular/core";
export declare const DEFAULT_LANGUAGE = "en";
export declare const DEFAULT_LOCALE_STRING = "en-ww";
export declare const DEFAULT_FALLBACK_REGION = "ww";
export interface Locale extends PlainObject {
    language: string;
    region: string;
}
export declare enum LocaleDiff {
    None = 0,
    Language = 1,
    Region = 2
}
export declare class LocaleService {
    private readonly document;
    private readonly configLoader;
    private readonly urlService;
    initialized: boolean;
    get locale(): Locale;
    set locale(value: Locale);
    readonly locale$: BehaviorSubject<Locale>;
    readonly isoValidLocaleString$: BehaviorSubject<string>;
    regionTranslations: RegionTranslations;
    private _regions;
    private _filteredRegions;
    get regions(): Region;
    get filteredRegions(): Region;
    get homeLink(): string;
    constructor(document: Document, configLoader: LocaleConfigLoaderService, urlService: UrlService);
    initializeLanguageAndCheckUrl(path?: string): Promise<void>;
    getTranslationName(): string;
    toTranslationName(urlLocale: string): string;
    getLocaleString(): string;
    /**
     * @returns safe iso language code with region part (e.g. de-de)
     */
    getIsoValidLocaleString(): LocaleString;
    setLocaleFromUrl(path?: string): Error | RegionNotSupportedError;
    updateLocale(region: string, language: string): Error | RegionNotSupportedError;
    setDefaultLocale(): void;
    updateCurrentRegion(): void;
    getRegionsAndLanguages(): Promise<void>;
    filterRegions(searchTerm: string): void;
    resetFilteredRegions(): void;
    getRegionUppercase(): string;
    getLocaleDifference(locale: Locale): LocaleDiff;
    private updateFilteredRegions;
    static ɵfac: i0.ɵɵFactoryDeclaration<LocaleService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<LocaleService>;
}
//# sourceMappingURL=locale.service.d.ts.map