import { BreakpointObserver } from '@angular/cdk/layout';
import { ElementRef } from '@angular/core';
import { BehaviorSubject, Observable, Subject } from 'rxjs';
import { BreakpointKey, BreakpointQuery } from '../types';
import { Viewport } from '../layout/viewport';
import * as i0 from "@angular/core";
export interface ResizeEvent {
    start: boolean;
    event: Event;
}
export declare const INITIAL_RESIZE_EVENT: ResizeEvent;
export declare class LayoutService {
    protected document: Document;
    protected breakpointObserver: BreakpointObserver;
    readonly headerHeight$: Subject<number>;
    readonly resizeEvent: Subject<ResizeEvent>;
    readonly resizeEventWithInitial$: BehaviorSubject<ResizeEvent>;
    readonly breakPointChangedEvent: Subject<string>;
    printModeEnabled: boolean;
    readonly expandForPrintPreview$: BehaviorSubject<boolean>;
    readonly screenHeight$: Observable<number>;
    readonly screenHeightPx$: Observable<string>;
    messageboxHeight: number;
    get scrollOffset(): number;
    get scrollPosition$(): Observable<number>;
    get currentBreakpoint(): BreakpointQuery;
    get currentViewport(): BreakpointKey;
    get isTouchDevice(): boolean;
    currentBreakpoint$: BehaviorSubject<string>;
    currentViewPort$: Observable<BreakpointKey>;
    currentViewportObj$: Observable<Viewport>;
    private readonly resizeObservable$;
    private readonly scrollObservable$;
    private emitResizeStart;
    private resizeStartEmitted;
    protected _currentBreakpoint: BreakpointQuery;
    private _isTouchDevice;
    private _isBodyOverflowing;
    private _scrollbarWidth;
    private disabledScrollCounter;
    private readonly scrollPositionSubscription$;
    private readonly defaultDebounceTime;
    private readonly windowWrapper;
    constructor(document: Document, breakpointObserver: BreakpointObserver);
    isBreakpoint(...breakpointQuery: BreakpointQuery[]): boolean;
    isViewport(...breakpointKey: BreakpointKey[]): boolean;
    isViewport$(...breakpointKey: BreakpointKey[]): Observable<boolean>;
    getGridGutter(): number;
    saveFromEvent(target: Window, event: string): Observable<Event>;
    disableScroll(): void;
    enableScroll(): void;
    scrollToTop(): void;
    scrollToTopOnElement(selector: string): void;
    scrollToElementId(id: string, additionalOffset?: number): void;
    scrollToElementRef(elementRef: ElementRef, additionalOffset?: number): void;
    scrollToNativeElement(element: Element, additionalOffset?: number): void;
    /**
     * Scrolls to position taking header into consideration.
     */
    scrollTo(position: number): void;
    scrollToVerticalMiddle(element: HTMLElement): void;
    private scrollToElementPosition;
    getElementPosition(element: HTMLElement): number;
    shouldExpandHeader(scrollPosition: number): boolean;
    setGlobalCSSProperties(): void;
    getViewportWidth(): number;
    getElementWidth(el: ElementRef): number;
    getGridMargin(): number;
    getBreakpointKeyForValue(value: number): BreakpointKey;
    private getGridMarginDefinition;
    getContainerWidth(): number;
    private subscribeToScroll;
    private subscribeToResize;
    private listenToBreakpointChanges;
    private detectTouchDevice;
    private checkScrollbar;
    getScrollbarWidth(): number;
    private setScrollbar;
    private resetScrollbar;
    static ɵfac: i0.ɵɵFactoryDeclaration<LayoutService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<LayoutService>;
}
//# sourceMappingURL=layout.service.d.ts.map