/**
 * Type describing navigation of certain components handled outside the ui library
 */
export type UiNavigationModel = UiBasicNavigationModel | UiRouteNavigationModel;
/**
 * Base type containing common attributes
 */
export interface UiBaseLinkModel {
    label?: string;
}
/**
 * Possible link targets
 *
 * @see https://developer.mozilla.org/en-US/docs/Web/HTML/Element/a#attr-target
 */
export type UiBasicNavigationTarget = '_blank' | '_self';
/**
 * Type containing attributes for regular browser navigation
 */
export interface UiBasicNavigationModel extends UiBaseLinkModel {
    type: 'url';
    href: string;
    target?: UiBasicNavigationTarget;
}
/**
 * Type containing attributes for routing navigation
 */
export interface UiRouteNavigationModel extends UiBaseLinkModel {
    type: 'route';
    route: string;
}
/**
 * Even type for when navigation is requested on a component
 */
export interface UiLinkClickedEventModel {
    link: UiNavigationModel;
}
//# sourceMappingURL=ui-navigation-model.d.ts.map