import { TemplateRef } from '@angular/core';
import { UiBaseAccordionItem } from '../ui-accordion-types';
import { SieIcon, SieIconRegistryService } from '@siemens/icons';
import * as i0 from "@angular/core";
/**
 * This directive is used to display items within an accordion and for setting their parameter values.
 */
export declare class UiAccordionItemDirective implements UiBaseAccordionItem {
    templateRef: TemplateRef<unknown>;
    iconReg: SieIconRegistryService;
    /**
     * Defines the headline that is shown above the accordion item.
     */
    headline: string;
    /**
     * Defines optional subheadline shown below headline in open and closed state
     */
    subHeadline: string;
    /**
     * Defines the identification of the accordion item.
     */
    id: string;
    /**
     * @param value Defines if the top border on accordion item should be shown.
     * @default false
     */
    set showTopBorder(value: boolean);
    get showTopBorder(): boolean;
    /**
     * @param value Defines the look of the headline: regular or bold (enhanced, bigger)
     * @default false
     */
    set headlineBold(value: boolean);
    get headlineBold(): boolean;
    /**
     * @param icon {@link SieIcon Icon} Defines optional custom icon at the beggining of headline
     */
    set icon(icon: SieIcon);
    get icon(): SieIcon;
    /**
     * @param value Defines if the accordion item should be expanded.
     * @default false
     */
    set open(value: boolean);
    get open(): boolean;
    private _showTopBorder;
    private _open;
    private _headlineBold;
    private _icon;
    constructor(templateRef: TemplateRef<unknown>, iconReg: SieIconRegistryService);
    static ɵfac: i0.ɵɵFactoryDeclaration<UiAccordionItemDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<UiAccordionItemDirective, "[sieUiAccordionItem]", never, { "headline": { "alias": "headline"; "required": false; }; "subHeadline": { "alias": "subHeadline"; "required": false; }; "id": { "alias": "id"; "required": false; }; "showTopBorder": { "alias": "showTopBorder"; "required": false; }; "headlineBold": { "alias": "headlineBold"; "required": false; }; "icon": { "alias": "icon"; "required": false; }; "open": { "alias": "open"; "required": false; }; }, {}, never, never, false, never>;
}
//# sourceMappingURL=ui-accordion-item.directive.d.ts.map