import { UiComponentType } from '../shared/services/webcomponents/ui-dom-manipulation.service';
export interface UiAccordionExpandEvent {
    /**
     * Defines if the clicked accordion item is expanded.
     */
    open: boolean;
    /**
     * Defines the index of clicked accordion item.
     */
    index: number;
}
export interface UiBaseAccordionItem {
    /**
     * Defines the headline that is shown above the accordion item.
     */
    headline: string;
    /**
     * Defines optional subheadline shown below headline in open and closed state
     */
    subHeadline: string;
    /**
     * Defines if the top border on accordion item should be shown.
     */
    showTopBorder: boolean;
    /**
     * Defines the look of the headline: regular or bold (enhanced, bigger)
     */
    headlineBold: boolean;
    /**
     *  Defines optional custom icon at the beginning of headline
     */
    icon: string;
    /**
     * Defines if the accordion item should be expanded by default.
     */
    open: boolean;
    /**
     * Defines the identification of the accordion item.
     */
    id: string;
}
export interface UiBaseAccordionItemHeader {
    /**
     * Used to display custom header content for a specific accordion item with matching id
     */
    parentId?: string;
}
export interface UiNewAccordionItem extends UiBaseAccordionItem {
    /**
     * Defines the content of an accordion item.
     */
    html: string;
}
export interface UiAccordionChanges {
    /**
     * Text that is supposed to replace the current headline of the accordion item.
     */
    headline?: string;
    /**
     * Defines optional subheadline shown below headline in open and closed state
     */
    subHeadline?: string;
    /**
     * Defines the look of the headline: regular or bold (enhanced, bigger)
     */
    headlineBold?: boolean;
    /**
     *  Defines optional custom icon at the beginning of headline
     */
    icon?: string;
    /**
     * ID that is supposed to replace the current accordion item id.
     */
    id?: string;
    /**
     * HTML that is supposed to replace the current content of the accordion item.
     */
    html?: string;
}
/** @ignore */
export interface UiAccordionItem extends UiBaseAccordionItem, UiComponentType {
}
/** @ignore */
export interface UiAccordionItemHeader extends UiBaseAccordionItemHeader, UiComponentType {
}
/** @ignore */
export type ElementWithDataAttributes = HTMLOrSVGElement & InnerHTML;
//# sourceMappingURL=ui-accordion-types.d.ts.map