import { AfterViewInit, ChangeDetectorRef, ElementRef, OnDestroy, QueryList } from '@angular/core';
import { UiAccordionItemDirective } from '../ui-accordion-item/ui-accordion-item.directive';
import { Subject } from 'rxjs';
import { UiAccordionChanges, UiAccordionExpandEvent, UiAccordionItem, UiAccordionItemHeader, UiBaseAccordionItemHeader, UiNewAccordionItem } from '../ui-accordion-types';
import { UiAccordionComponentService } from './ui-accordion.component.service';
import { UiAccordionItemHeaderDirective } from '../ui-accordion-item/ui-accordion-item-header.directive';
import * as i0 from "@angular/core";
/**
 * # Accordion component
 *
 * Accordions are used to structure content under several accordion items that can be collapsed and expanded.
 *
 * ## Component variations
 *
 * There are no variations.
 *
 * ## Content
 *
 * The content of accordion items can be passed as child elements with using `UiAccordionItemDirective`.
 * Custom content of accordion item`s header can be passed as child element using `UiAccordionItemHeaderDirective`.
 * In order to display custom header content, header`s parentId must match the id of an accordion item we want to adapt.
 *
 * See the example below.
 *
 * ## Code example
 * @example
 *  ```html
 * <sie-ui-accordion>
 *   <ng-template sieUiAccordionItemHeader parentId="first">
 *      <sie-ui-button>custom content</sie-ui-button>
 *   </ng-template>
 *   <ng-template sieUiAccordionItem id="first" headline="Headline 1"> Item 1</ng-template>
 *   <ng-template sieUiAccordionItem headline="This accordion item is set to be opened by default" [open]="true">
 *      Item 2
 *   </ng-template>
 *   <ng-template
 *     sieUiAccordionItem
 *     headline="Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt"
 *   >
 *     Item 3
 *   </ng-template>
 * </sie-ui-accordion>
 * ```
 */
export declare class UiAccordionComponent implements AfterViewInit, OnDestroy {
    private readonly cdr;
    private readonly uiAccordionComponentService;
    /** @ignore */
    items: QueryList<UiAccordionItemDirective> | UiAccordionItem[];
    /** @ignore */
    headers: QueryList<UiAccordionItemHeaderDirective> | UiAccordionItemHeader[];
    /**
     * {@link UiAccordionExpandEvent Event} triggered when a different accordion item is selected.
     */
    expandedChange: Subject<UiAccordionExpandEvent>;
    /** @ignore */
    elementsRef: ElementRef;
    /** @ignore */
    headerSlots: UiBaseAccordionItemHeader[];
    private readonly subscriptions;
    constructor(cdr: ChangeDetectorRef, uiAccordionComponentService: UiAccordionComponentService<unknown, UiAccordionComponent>);
    /** @ignore */
    ngAfterViewInit(): void;
    /** @ignore */
    ngOnDestroy(): void;
    /** @ignore */
    itemClicked(open: boolean, index: number): void;
    /**
     * Triggers the change detection of the component.
     */
    updateView(): void;
    /** @ignore */
    private matchItemAndHeaderIds;
    private extractArray;
    /** @ignore Use only intended in web components */
    removeItems(): void;
    /** @ignore Use only intended in web components */
    removeItemAt(index: number): void;
    /** @ignore Use only intended in web components */
    toggleItemAt(index: number): void;
    /** @ignore Use only intended in web components */
    set newItem(item: UiNewAccordionItem);
    /** @ignore Use only intended in web components */
    updateItem(index: number, changes: UiAccordionChanges): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiAccordionComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiAccordionComponent, "sie-ui-accordion", never, { "removeItems": { "alias": "removeItems"; "required": false; }; "removeItemAt": { "alias": "removeItemAt"; "required": false; }; "toggleItemAt": { "alias": "toggleItemAt"; "required": false; }; "newItem": { "alias": "newItem"; "required": false; }; "updateItem": { "alias": "updateItem"; "required": false; }; }, { "expandedChange": "expandedChange"; }, ["items", "headers"], [".item", ".header"], false, never>;
}
//# sourceMappingURL=ui-accordion.component.d.ts.map