import { ElementRef } from '@angular/core';
import { ThemeVariant } from '@siemens/core';
import { SieIconRegistryService } from '@siemens/icons';
import { BadgeIcon, BadgeStatus, BadgeType } from './ui-badge.types';
import * as i0 from "@angular/core";
/**
 * # Badge component
 *
 * Badges are used to notify the user about the change in a status of item.
 *
 * ## Component variations
 *
 * - Dot badge
 * - Icon badge
 * - Number badge
 *
 * ## Content
 *
 * The badge component does not accept any content.
 *
 * ## Code example
 * @example ```html
 * <sie-ui-badge [type]="'dot'" [status]="'error'" [mode]="'light'"></sie-ui-badge>
 * <sie-ui-badge [type]="'icon'" [status]="'success'"></sie-ui-badge>
 * <sie-ui-badge [type]="'counter'" [number]="9"></sie-ui-badge>
 * ```
 */
export declare class UiBadgeComponent {
    readonly iconReg: SieIconRegistryService;
    /** @ignore */
    badge: ElementRef;
    /**
     * {@link ThemeVariant Theme} of the badge.
     * @default 'light'
     */
    mode: ThemeVariant;
    /**
     * {@link BadgeType Type} of the badge.
     */
    type: BadgeType;
    /**
     * @param num Present the current value for the badge. Parameter is applicable only when type = `counter`.
     */
    set number(num: number);
    get number(): number;
    /**
     * @param value When it is true a border is applied for the badge. Parameter is applicable only when type = `counter`.
     * @default false
     */
    set addOutline(value: boolean);
    get addOutline(): boolean;
    /**
     * @param value  When it is true the background is changed for the badge. Parameter is applicable only when type = `counter`.
     * @default false
     */
    set highlighted(value: boolean);
    get highlighted(): boolean;
    /**
     * @param status Defines the {@link BadgeStatus} of the badge. Parameter is applicable only when type = `icon`.
     */
    set status(status: BadgeStatus);
    get status(): BadgeStatus;
    get iconName(): BadgeIcon;
    /** @ignore */
    value: string;
    /** @ignore */
    oldValue: string;
    /** @ignore */
    initialValue: boolean;
    /** @ignore */
    hide: boolean;
    /** @ignore */
    digitChange: boolean;
    /** @ignore */
    widthBeforeDigitChange: number;
    private _icon;
    private _status;
    private _addOutline;
    private _highlighted;
    private _number;
    constructor(iconReg: SieIconRegistryService);
    /** @ignore */
    onAnimationEnd(event: AnimationEvent): void;
    /** @ignore */
    onDigitChange(): void;
    private checkDigitChange;
    private getNewValue;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiBadgeComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiBadgeComponent, "sie-ui-badge", never, { "mode": { "alias": "mode"; "required": false; }; "type": { "alias": "type"; "required": false; }; "number": { "alias": "number"; "required": false; }; "addOutline": { "alias": "addOutline"; "required": false; }; "highlighted": { "alias": "highlighted"; "required": false; }; "status": { "alias": "status"; "required": false; }; }, {}, never, never, false, never>;
}
//# sourceMappingURL=ui-badge.component.d.ts.map