import { UiBarChartAlignment, UiBarChartSize, UiBarChartVariant, UiBarPartial } from './ui-bar-chart.types';
import * as i0 from "@angular/core";
/**
 * # Bar chart component
 *
 * Bar charts are used to provide a specific type of visual representation of given data. They help to quickly grasp
 * the information visually which is otherwise available in complex text format.
 *
 * ## Component variations
 *
 * - distribution
 * - progress
 *
 * ## Content
 *
 * The bar chart component accepts valid HTML markup to be displayed in the popover.
 *
 * @example
 * With Textual Popover:
 * ```html
 * <sie-ui-bar-chart variant="progress" [partials]="barChartPartials" size="small" [popoverText]="'Popover Text'">
 * </sie-ui-bar-chart>
 * ```
 *
 * With HTML Popover:
 * ```html
 * <sie-ui-bar-chart variant="progress" [partials]="barChartPartials" size="small">
 *   <span popover>Popover HTML</span>
 * </sie-ui-bar-chart>
 * ```
 */
export declare class UiBarChartComponent {
    /**
     * Defines {@link UiBarChartVariant variant} of the bar chart.
     * @default 'distribution'
     */
    variant: UiBarChartVariant;
    /**
     * Defines {@link UiBarChartSize size} of the bar chart.
     * @default 'regular'
     */
    size: UiBarChartSize;
    /**
     * Defines {@link UiBarChartAlignment alignment} of the bar chart.
     * @default 'horizontal'
     */
    alignment: UiBarChartAlignment;
    /**
     * @param popoverText Defines the text shown in the popover.
     */
    popoverText: string;
    /**
     * Defines {@link UiBarPartial partials} used to render the bar chart.
     * @default '[]'
     */
    partials: UiBarPartial[];
    static ɵfac: i0.ɵɵFactoryDeclaration<UiBarChartComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiBarChartComponent, "sie-ui-bar-chart", never, { "variant": { "alias": "variant"; "required": false; }; "size": { "alias": "size"; "required": false; }; "alignment": { "alias": "alignment"; "required": false; }; "popoverText": { "alias": "popoverText"; "required": false; }; "partials": { "alias": "partials"; "required": false; }; }, {}, never, ["[popover]"], false, never>;
}
//# sourceMappingURL=ui-bar-chart.component.d.ts.map