import { AfterViewInit, ChangeDetectorRef, ElementRef } from '@angular/core';
import { SieIcon, SieIconRegistryService } from '@siemens/icons';
import { Subject } from 'rxjs';
import { UiSpinnerSize } from '../../ui-spinner/ui-spinner.types';
import { UiButtonIconPosition, UiButtonPosition, UiButtonProminence, UiButtonThemeType, UiButtonType, UiButtonVariant } from './ui-button.types';
import { ClassDefinition, PlainObject, ThemeVariant } from '@siemens/core';
import * as i0 from "@angular/core";
export declare abstract class UiBaseButtonDirective implements AfterViewInit {
    private readonly cdr;
    iconReg: SieIconRegistryService;
    /** @ignore */
    buttonElement: ElementRef;
    /**
     * Sets the URL for the link if the button type is `link`.
     */
    link?: string;
    /**
     * Defines where the link should be opened if the button type is `link`.
     * @default '_self'
     */
    target?: string;
    /**
     * Defines the {@link UiButtonThemeType theme type} of the button.
     * @default 'main'
     */
    themeType?: UiButtonThemeType;
    /**
     * Defines the {@link UiButtonVariant variant} of the button.
     * @default 'primary'
     */
    variant?: UiButtonVariant;
    /**
     * Defines the {@link UiButtonPosition position} of where the button is placed.
     * @default 'content'
     */
    position?: UiButtonPosition;
    /**
     * Defines on which {@link ThemeVariant background} the button is placed.
     * @default 'light'
     */
    background?: ThemeVariant;
    /**
     * Defines the {@link UiButtonProminence prominence} of the button (used only with the icon buttons).
     */
    prominence?: UiButtonProminence;
    /**
     * Defines the {@link UiButtonIconPosition position of the icon} within the button.
     * @default 'leading'
     */
    iconPosition: UiButtonIconPosition;
    /**
     * Sets the screen reader text for the icon.
     * @default ''
     */
    iconScreenReaderText: string;
    /**
     * Sets the custom css class on the button element. To add multiple classes provide the string with the whitespace
     * between classes, e.g.: `class-a class-b`.
     * @default ''
     */
    cssClass: string;
    /**
     * Allows for the secondary icon to rotate on the button click.
     * @default false
     */
    isSecondaryIconRotated: boolean;
    /**
     * @param buttonType Defines the {@link UiButtonType type of the button}.
     * @default 'button'
     */
    set buttonType(buttonType: UiButtonType);
    get buttonType(): UiButtonType;
    /**
     * @param value Defines if the button has increased size.
     * @default false
     */
    set increasedSize(value: boolean);
    get increasedSize(): boolean;
    /**
     * @param value Defines if the line break should be disabled.
     * @default true
     */
    set disableLineBreak(value: boolean);
    get disableLineBreak(): boolean;
    /**
     * @param value Defines if the button is disabled.
     * @default false
     */
    set disabled(value: boolean);
    get disabled(): boolean;
    /**
     * @param value Defines if the button has a badge.
     * @default false
     */
    set badge(value: boolean);
    get badge(): boolean;
    /**
     * @param value Defines the numeral value inside the badge (applicable only if the badge is set to true).
     */
    set badgeNumber(value: number);
    get badgeNumber(): number;
    /**
     * @param value Defines if the text inside the button is bold.
     * @default true
     */
    set bold(value: boolean);
    get bold(): boolean;
    /**
     * @param value Defines if the button is focusable.
     * @default true
     */
    set focusable(value: boolean);
    get focusable(): boolean;
    /**
     * @param value Defines if the hovering over button is disabled.
     * @default false
     */
    set hoverDisabled(value: boolean);
    get hoverDisabled(): boolean;
    /**
     * @param value Add additional attributes to the button component (e.g.: for tracking).
     */
    set dataAttributes(value: PlainObject);
    get dataAttributes(): PlainObject;
    /**
     * @param fullWidth Defines if the button has full width.
     * @default false
     */
    set fullWidth(fullWidth: boolean);
    get fullWidth(): boolean;
    /**
     * @param withSpinner Defines if the button should have a spinner.
     * @default false
     */
    set withSpinner(withSpinner: boolean);
    get withSpinner(): boolean;
    /**
     * @param icon Defines which icon should be shown inside the button.
     */
    set icon(icon: SieIcon);
    get icon(): SieIcon;
    /**
     * @param iconSecondary Adds secondary icon after the button text.
     */
    set iconSecondary(iconSecondary: SieIcon);
    get iconSecondary(): SieIcon;
    /**
     * @param showSpinner Defines if the spinner should be shown.
     * @default false
     */
    set showSpinner(showSpinner: boolean);
    get showSpinner(): boolean;
    /**
     * Event triggered when the button is clicked.
     */
    clicked: Subject<Event>;
    /**
     * Event triggered when the button is focused.
     */
    focused: Subject<Event>;
    /**
     * Event triggered when the button is blurred.
     */
    blurred: Subject<Event>;
    /** @ignore */
    isButton: boolean;
    /** @ignore */
    dimensionsSet: boolean;
    private viewInitialized;
    private _withSpinner;
    private _showSpinner;
    private _spinnerAnimating;
    private _shouldFadeOutText;
    private _icon;
    private _iconSecondary;
    private _buttonWithSpinnerWidth;
    private _fullWidth;
    private _buttonType;
    private _badgeNumber?;
    private _increasedSize;
    private _disableLineBreak;
    private _disabled;
    private _badge;
    private _bold;
    private _focusable;
    private _hoverDisabled;
    private _dataAttributes;
    protected constructor(cdr: ChangeDetectorRef, iconReg: SieIconRegistryService);
    /**
     * Readonly property containing information if the spinner on the button is animating.
     */
    get spinnerAnimating(): boolean;
    /**
     * Readonly property containing information if the text on the button should fade out.
     */
    get shouldFadeOutText(): boolean;
    /**
     * Readonly property containing information on the width of the button with active spinner.
     */
    get buttonWithSpinnerWidth(): number;
    /** @ignore */
    get spinnerSize(): UiSpinnerSize;
    /** @ignore */
    ngAfterViewInit(): void;
    /** @ignore */
    onClick(event: Event): void;
    /**
     * Focuses the button.
     */
    focusButton(): void;
    /** @ignore */
    onFocus(event: Event): void;
    /** @ignore */
    onBlur(event: Event): void;
    /** @ignore */
    onAnimationEnd(): void;
    private setSpinnerDimensions;
    /** @ignore */
    getIconClasses(): ClassDefinition;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiBaseButtonDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<UiBaseButtonDirective, never, never, { "link": { "alias": "link"; "required": false; }; "target": { "alias": "target"; "required": false; }; "themeType": { "alias": "themeType"; "required": false; }; "variant": { "alias": "variant"; "required": false; }; "position": { "alias": "position"; "required": false; }; "background": { "alias": "background"; "required": false; }; "prominence": { "alias": "prominence"; "required": false; }; "iconPosition": { "alias": "iconPosition"; "required": false; }; "iconScreenReaderText": { "alias": "iconScreenReaderText"; "required": false; }; "cssClass": { "alias": "cssClass"; "required": false; }; "isSecondaryIconRotated": { "alias": "isSecondaryIconRotated"; "required": false; }; "buttonType": { "alias": "buttonType"; "required": false; }; "increasedSize": { "alias": "increasedSize"; "required": false; }; "disableLineBreak": { "alias": "disableLineBreak"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "badge": { "alias": "badge"; "required": false; }; "badgeNumber": { "alias": "badgeNumber"; "required": false; }; "bold": { "alias": "bold"; "required": false; }; "focusable": { "alias": "focusable"; "required": false; }; "hoverDisabled": { "alias": "hoverDisabled"; "required": false; }; "dataAttributes": { "alias": "dataAttributes"; "required": false; }; "fullWidth": { "alias": "fullWidth"; "required": false; }; "withSpinner": { "alias": "withSpinner"; "required": false; }; "icon": { "alias": "icon"; "required": false; }; "iconSecondary": { "alias": "iconSecondary"; "required": false; }; "showSpinner": { "alias": "showSpinner"; "required": false; }; }, { "clicked": "clicked"; "focused": "focused"; "blurred": "blurred"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-base-button.directive.d.ts.map