import { ChangeDetectorRef } from '@angular/core';
import { UiBaseButtonDirective } from './ui-base-button.directive';
import { SieIconRegistryService } from '@siemens/icons';
import * as i0 from "@angular/core";
/**
 * # Button component
 *
 * Buttons are used to trigger some kind of action such as submitting, deleting, showing or hiding the content.
 * They can also act as a link where they can get us to another page.
 *
 * ## Component variations
 *
 * Button type:
 * - button
 * - submit
 * - link
 *
 * Theme type:
 * - main (primary, secondary, tertiary)
 * - icon
 * - uncontained
 *
 * Additionally, there are variations with and without the spinner.
 *
 * ## Content
 *
 * The label of the button component can be any valid markup.
 * It will not be considered if button is of `icon` theme type.
 *
 * ## Code example
 * @example ```html
 * <h2>Regular button</h2>
 * <sie-ui-button>Primary Button</sie-ui-button>
 *
 * <h2>Icon button</h2>
 * <sie-ui-button
 *  theme-type="icon"
 *  variant="icon-un-contained"
 *  position="content"
 *  [icon]="'ShoppingCart'"
 *  background="dark"
 * ></sie-ui-button>
 *
 * <h2>Uncontained button</h2>
 * <sie-ui-button theme-type="un-contained">Uncontained Button</sie-ui-button>
 * ```
 */
export declare class UiButtonComponent extends UiBaseButtonDirective {
    constructor(cdr: ChangeDetectorRef, iconReg: SieIconRegistryService);
    static ɵfac: i0.ɵɵFactoryDeclaration<UiButtonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiButtonComponent, "sie-ui-button", never, {}, {}, never, ["*"], false, never>;
}
//# sourceMappingURL=ui-button.component.d.ts.map