import { UiButtonIconPosition, UiButtonPosition, UiButtonProminence, UiButtonThemeType, UiButtonType, UiButtonVariant } from './ui-button.types';
import { SieIcon } from '@siemens/icons';
import { PlainObject, ThemeVariant } from '@siemens/core';
export interface UiButtonModel {
    /**
     * Identifier of the button.
     */
    id?: string;
    /**
     * Label of the button.
     */
    label?: string;
    /**
     * The URL for the link if button type is `link`.
     */
    link?: string;
    /**
     * {@link UiButtonType Type} of the button.
     */
    buttonType: UiButtonType;
    /**
     * Target for the link if button type is `link`.
     */
    target?: string;
    /**
     * Button {@link UiButtonVariant variant}.
     */
    variant?: UiButtonVariant;
    /**
     * Defines on which {@link ThemeVariant background} the button is placed.
     */
    background?: ThemeVariant;
    /**
     * Defines the {@link UiButtonProminence prominence} of the button (used only with the icon buttons).
     */
    prominence?: UiButtonProminence;
    /**
     * Defines which {@link SieIcon icon} should be shown inside the button.
     */
    icon?: SieIcon;
    /**
     * Secondary {@link SieIcon icon} after the button text.
     */
    iconSecondary?: SieIcon;
    /**
     * {@link UiButtonIconPosition Position of the icon} within the button.
     */
    iconPosition?: UiButtonIconPosition;
    /**
     * Defines the {@link UiButtonPosition position} of where the button is placed.
     */
    position?: UiButtonPosition;
    /**
     * Screen reader text for the icon.
     */
    iconScreenReaderText?: string;
    /**
     * Sets the custom css class on the button element. To add multiple classes provide the string with the whitespace
     * between classes, e.g.: `class-a class-b`.
     */
    cssClass?: string;
    /**
     * Allows for the secondary icon to rotate on the button click.
     */
    isSecondaryIconRotated?: boolean;
    /**
     * Defines if the button is disabled.
     */
    disabled?: boolean;
    /**
     * Defines if the button should take the full width.
     */
    fullWidth?: boolean;
    /**
     * Defines if the line break should be disabled.
     */
    disableLineBreak?: boolean;
    /**
     * Add additional attributes to the button component (e.g.: for tracking).
     */
    dataAttributes?: PlainObject;
    /**
     * Defines if the button could have spinner.
     */
    withSpinner?: boolean;
    /**
     * Defines if the spinner should be shown.
     */
    showSpinner?: boolean;
    /**
     * Defines the {@link UiButtonThemeType theme type} of the button.
     * @default 'main'
     */
    themeType?: UiButtonThemeType;
    /**
     * Defines if the button has a badge.
     */
    badge?: boolean;
    /**
     * Defines the numeral value inside the badge (applicable only if the badge is set to true).
     */
    badgeNumber?: number;
    /**
     * Defines if the button has increased size.
     */
    increasedSize?: boolean;
    /**
     * Defines if the text inside the button is bold.
     */
    bold?: boolean;
    /**
     * Defines if the button is focusable.
     */
    focusable?: boolean;
    /**
     * Defines if the hover over the button is disabled.
     */
    hoverDisabled?: boolean;
}
/**
 * Event to be thrown on button click.
 */
export interface UiButtonClickModel {
    /**
     * Identifies the {@link UiButtonModel button}.
     */
    button: UiButtonModel;
    /**
     * Event which will be triggered on the button click.
     */
    event: Event;
}
//# sourceMappingURL=ui-button.model.d.ts.map