import { ChangeDetectorRef, ElementRef, EventEmitter, OnChanges, OnDestroy, OnInit, Renderer2, SimpleChanges } from '@angular/core';
import { LayoutService, LocaleString, ThemeVariant } from '@siemens/core';
import { UiCardArrangementItem } from '../ui-card-arrangement-item.type';
import { Subject } from 'rxjs';
import { UiCardsContainerService } from '../ui-cards-container/ui-cards-container.service';
import { UiCarouselComponent } from '../../ui-carousel/ui-carousel.component';
import { Orientation, ViewportSetting } from './ui-cards-arrangement.constants';
import { BreakpointObserver } from '@angular/cdk/layout';
import { UiButtonClickModel } from '../../ui-button/base/ui-button.model';
import { UiChildActionEventModel } from '../../shared/models/child-action-event.model';
import { UiLinkClickedEventModel } from '../../shared/models/ui-navigation-model';
import { UiCarouselScreenReader } from '../../ui-carousel/ui-carousel.types';
import * as i0 from "@angular/core";
export declare class UiCardsArrangementComponent implements OnInit, OnDestroy, OnChanges {
    private readonly breakpointObserver;
    private readonly layoutService;
    private readonly cd;
    private readonly cardsContainerService;
    private readonly elementRef;
    private readonly renderer;
    carousel: UiCarouselComponent;
    set items(value: UiCardArrangementItem[]);
    orientation: Orientation;
    theme: ThemeVariant;
    menuButtonScreenReaderText: string;
    /**
     * Locale being used for formatting purposes
     */
    locale: LocaleString;
    /**
     * @param value Defines screen reader texts for Carousel functions.
     */
    carouselScreenReaderText: UiCarouselScreenReader;
    /**
     * Defines if container-queries or media-queries are used for the carousel styling
     * @default false
     */
    containerStyled: boolean;
    /**
     * Defines whether this carousel will be rendered in the cut-off version.
     * NOTE: if cutOff is enabled containerStyled doesn't work
     * @default true
     */
    cutOff: boolean;
    buttonClick: Subject<UiButtonClickModel>;
    childActionClicked: EventEmitter<UiChildActionEventModel>;
    linkClicked: EventEmitter<UiLinkClickedEventModel>;
    cardClicked: EventEmitter<UiCardArrangementItem>;
    _items: UiCardArrangementItem[];
    viewportSettings: ViewportSetting;
    slides: any[][][];
    containerWidth: number;
    private previousItemsPerPage;
    private readonly subscriptions;
    constructor(breakpointObserver: BreakpointObserver, layoutService: LayoutService, cd: ChangeDetectorRef, cardsContainerService: UiCardsContainerService, elementRef: ElementRef, renderer: Renderer2);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    onButtonClick(event: UiButtonClickModel): void;
    onChildActionSelected(event: UiChildActionEventModel): void;
    onContainerWidthChange(containerWidth: number): void;
    private updateContainerConfigurations;
    private getElementContainerWidth;
    private getBreakpointKeyForContainerWidth;
    private createCarouselSettings;
    private getSettingsForContainerWidth;
    private getBreakpointQueriesForOrientation;
    private handleViewportChange;
    private arrange;
    private arrangeSlide;
    private getSettingsForViewport;
    private rearrangeCarousel;
    private calculateCardWidth;
    private listenToSizeChange;
    onLinkClicked(event: UiLinkClickedEventModel): void;
    onCardClicked(event: UiCardArrangementItem): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiCardsArrangementComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiCardsArrangementComponent, "sie-ui-cards-arrangement", never, { "items": { "alias": "items"; "required": false; }; "orientation": { "alias": "orientation"; "required": false; }; "theme": { "alias": "theme"; "required": false; }; "menuButtonScreenReaderText": { "alias": "menuButtonScreenReaderText"; "required": false; }; "locale": { "alias": "locale"; "required": false; }; "carouselScreenReaderText": { "alias": "carouselScreenReaderText"; "required": false; }; "containerStyled": { "alias": "containerStyled"; "required": false; }; "cutOff": { "alias": "cutOff"; "required": false; }; }, { "buttonClick": "buttonClick"; "childActionClicked": "childActionClicked"; "linkClicked": "linkClicked"; "cardClicked": "cardClicked"; }, never, never, false, never>;
    static ngAcceptInputType_containerStyled: unknown;
    static ngAcceptInputType_cutOff: unknown;
}
//# sourceMappingURL=ui-cards-arrangement.component.d.ts.map