import { PlainObject } from '@siemens/core';
import { UiDropdownMenuModel } from '../ui-dropdown-menu/ui-dropdown-menu.model';
export interface UiBaseCardModel {
    title?: string;
    /**
     * Add additional attributes to the button component (e.g.: for tracking).
     */
    dataAttributes?: PlainObject;
    /**
     * Available {@link UiDropdownMenuModel list of actions} in the dropdown (when you click the options button).
     */
    childActions?: UiDropdownMenuModel[];
    /**
     * Defines the content type of the item (event)
     */
    contentType?: string;
}
export interface UiCategoryCardModel {
    /**
     * Defines the type (category) of the item and the icon that's displayed inside a tag. `Manual`, `Download`,
     * `Certificate`, `Faq`, `ExampleOfUse`, `Characteristic`, `Catalog`, `ProductNote` , `TechnicalData` and `TopicPage`
     * will display the icon specific to each type. Other values will just display icon `File` as the default icon.
     */
    tagLabel?: string;
    /**
     * Defines the type (category) of the item and the icon that's displayed as media.
     * - Tips on how the correlation of `dataType` and `tagLabel` should work:
     * | type             | tagLabel               |
     * | :----------------| :----------------------|
     * | `Manual`         |  `Manual`              |
     * | `Download`       |  `Download`            |
     * | `Certificate`    |  `Certificate`         |
     * | `Faq`            |  `FAQ`                 |
     * | `ExampleOfUse`   |  `Application example`|
     * | `Characteristic` |  `Characteristic`      |
     * | `Catalog`        |  `Catalogue/brochure`  |
     * | `ProductNote`    |  `Product note`        |
     * | `TechnicalData`  |  `Technical data`      |
     * | `TopicPage`      |  `Topic Page`          |
     */
    type?: string;
}
export interface UiRateableCard {
    /**
     * The rating of the item.
     */
    rating?: number;
    /**
     * The tooltip label of the rating
     */
    tooltipLabel?: string;
    /**
     * The count of reviews next to the rating.
     */
    ratingCount?: number;
}
export interface UiLinkableCard {
    /**
     * The link that the item leads us to.
     */
    linkToItem?: string;
}
export interface UiDateAndVersionCard {
    documentDate?: string;
    /**
     * Version of the item.
     */
    version?: string;
}
export interface UiVisualizationTypeCard {
    /**
     * Defines the type of the item.
     */
    visualizationType?: string;
}
//# sourceMappingURL=ui-cards.model.d.ts.map