import { ChangeDetectorRef, EventEmitter, OnInit } from '@angular/core';
import { CheckboxChangedModel, CheckboxModel } from './ui-checkbox-group.models';
import { SieIconRegistryService } from '@siemens/icons';
import { NgFormControlDirective } from '../../ui-form-control/ui-ng-form-control.directive';
import { ValidationErrors } from '@angular/forms';
import * as i0 from "@angular/core";
/**
 * # Checkbox Group component
 *
 * Checkboxes are part of a form, allowing us to select or deselect a given option. Similarly, the Checkbox Group allows
 * us to choose between listed options.
 *
 * ## Component variations
 *
 * There are no variations as this component groups multiple checkboxes together
 *
 * ## Content
 *
 * The checkbox group component does not accept any content.
 *
 * ## Code example
 * @example ```html
 * <form #form="ngForm">
 *   <sie-ui-checkbox-group
 *     [items]="[
 *       {
 *         label: 'Option Label 1',
 *         hint: {
 *           content: 'help text here',
 *           type: 'tooltip'
 *         }
 *       }
 *     ]"
 *     [hint]="{
 *       content: 'Hint for the whole checkbox group (can only be inline!)',
 *       type: 'inline'
 *     }"
 *     required="true"
 *     label="Checkbox Group Label"
 *     name="checkboxGroup"
 *   ></sie-ui-checkbox-group>
 * </form>
 * ```
 */
export declare class UiCheckboxGroupComponent extends NgFormControlDirective implements OnInit {
    readonly iconReg: SieIconRegistryService;
    private readonly cdr;
    /**
     * Defines the items of the checkbox group. See {@link CheckboxModel}
     */
    items: CheckboxModel[];
    /**
     * @param required Defines if the checkbox group is required or not (overrides the required flag of the checkbox items)
     * @default false
     */
    set required(required: boolean);
    get required(): boolean;
    private _required;
    /**
     * Event fired when one of the checkbox items is selected or deselected. See {@link CheckboxChangedModel}
     */
    valueChange: EventEmitter<CheckboxChangedModel>;
    constructor(iconReg: SieIconRegistryService, cdr: ChangeDetectorRef);
    /** @ignore */
    ngOnInit(): void;
    /** @ignore */
    onCheckboxChange(state: boolean, index: number, name: string): void;
    /** @ignore */
    validateInternal(): ValidationErrors | null;
    /** @ignore */
    writeValue(ids: string[]): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiCheckboxGroupComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiCheckboxGroupComponent, "sie-ui-checkbox-group", never, { "items": { "alias": "items"; "required": false; }; "required": { "alias": "required"; "required": false; }; }, { "valueChange": "valueChange"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-checkbox-group.component.d.ts.map