import { SieIcon } from '@siemens/icons';
import { HintModel } from '../../shared/models/hint.model';
import { BehaviorSubject } from 'rxjs';
export interface CheckboxModel {
    /** @ignore */
    labelTranslateKey?: string;
    /**
     * Defines the label of the checkbox
     */
    label?: string;
    /** @ignore */
    labelAppendix$?: BehaviorSubject<string>;
    /**
     * Defines the id of the checkbox
     */
    id?: string;
    /**
     * Defines the {@link HintModel hint} on the checkbox
     */
    hint?: HintModel;
    /**
     * Defines if the checkbox is required or not
     */
    required?: boolean;
    /**
     * Removes functionality (click events, expanding capability) from the checkbox and changes heading
     * color when set to true
     */
    disabled?: boolean;
    /**
     * Sets state of the component as readonly
     */
    readonly?: boolean;
    /**
     * Defines if the checkbox is active or not (Active state defines a visual difference to non-active ones)
     */
    active?: boolean;
    /**
     * Defines the value of the checkbox (used instead of checked)
     */
    value?: boolean;
    /**
     * Sets state of the component as invalid and adds style changes
     */
    invalid?: boolean;
    /**
     * Defines the icons to be displayed next to the checkbox
     */
    icons?: SieIcon[];
    /**
     * Defines if the checkbox is indeterminate or not
     */
    indeterminate?: boolean;
}
/**
 * Type for event when {@link UiCheckboxComponent checkbox} was checked/unchecked
 */
export interface CheckboxChangedModel {
    /**
     * Index of checkbox in the group
     */
    index: number;
    /**
     * Name of checkbox in the group
     */
    name: string;
    /**
     * Checked=`true` or unchecked=`false`
     */
    state: boolean;
}
//# sourceMappingURL=ui-checkbox-group.models.d.ts.map