import { EventEmitter, ElementRef } from '@angular/core';
import { NgFormControlDirective } from '../ui-form-control/ui-ng-form-control.directive';
import { SieIcon, SieIconRegistryService } from '@siemens/icons';
import { ValidationErrors } from '@angular/forms';
import { BehaviorSubject } from 'rxjs';
import * as i0 from "@angular/core";
/**
 * # Checkbox component
 *
 * Checkboxes are part of a form, allowing us to select or deselect a given option. Similarly, the Checkbox Group allows
 * us to choose between listed options.
 *
 * ## Component variations
 *
 * - standard (when `label` value (with or without `icons` value) is defined)
 * - condensed (when no `label`, except for the readonly state, nor `icons` value is defined)
 *
 * ## Content
 *
 * The checkbox component does not accept any content.
 *
 * ## Code example
 * @example ```html
 * <sie-ui-checkbox label="click me" [(value)]="active"></sie-ui-checkbox>
 *
 * Status: {{ active }}
 * ```
 */
export declare class UiCheckboxComponent extends NgFormControlDirective {
    readonly iconReg: SieIconRegistryService;
    set checkboxElement(checkboxInput: ElementRef);
    /**
     * Defines the id of the checkbox
     */
    id: string;
    /**
     * Used to add a focus to specific checkbox item
     */
    checkboxIdToFocus: string;
    /**
     * Event triggered when the checkbox is clicked.
     */
    valueChange: EventEmitter<boolean>;
    /**
     * @param indeterminate Defines if the checkbox is indeterminate or not
     * @default false
     */
    set indeterminate(indeterminate: boolean);
    get indeterminate(): boolean;
    /**
     * @param value Defines the value of the checkbox (used instead of checked)
     * @default false
     */
    set value(value: boolean);
    get value(): boolean;
    /**
     * @param active Defines the checkbox is active or not (Active state defines a visual difference to non-active ones)
     * @default false
     */
    set active(active: boolean);
    get active(): boolean;
    /**
     *  @param required Defines if the checkbox is required or not
     *  @default false
     */
    set required(required: boolean);
    get required(): boolean;
    /**
     * @param icons Defines the {@link SieIcon icons} to be displayed next to the checkbox
     */
    set icons(icons: SieIcon[]);
    get icons(): SieIcon[];
    /** @ignore */
    labelAppendix$?: BehaviorSubject<string>;
    private _icons;
    private _indeterminate;
    private _value;
    private _active;
    private _required;
    constructor(iconReg: SieIconRegistryService);
    /** @ignore */
    onCheck(checkBoxState: boolean): void;
    /** @ignore */
    validateInternal(): ValidationErrors | null;
    /** @ignore */
    writeValue(checked: boolean): void;
    /**
     * Sets the focus to the checkbox input field.
     */
    focus(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiCheckboxComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiCheckboxComponent, "sie-ui-checkbox", never, { "id": { "alias": "id"; "required": false; }; "checkboxIdToFocus": { "alias": "checkboxIdToFocus"; "required": false; }; "indeterminate": { "alias": "indeterminate"; "required": false; }; "value": { "alias": "value"; "required": false; }; "active": { "alias": "active"; "required": false; }; "required": { "alias": "required"; "required": false; }; "icons": { "alias": "icons"; "required": false; }; "labelAppendix$": { "alias": "labelAppendix$"; "required": false; }; }, { "valueChange": "valueChange"; }, never, ["[slot=label-content]"], false, never>;
}
//# sourceMappingURL=ui-checkbox.component.d.ts.map