import { ChangeDetectorRef, ElementRef, EventEmitter, OnInit } from '@angular/core';
import { DropdownType, UiDropdownComponent } from '../ui-dropdown';
import { UiEventPropagationService } from '../services/ui-event-propagation.service';
import { SieIconRegistryService } from '@siemens/icons';
import { LayoutService } from '@siemens/core';
import { CdkOverlayService } from '../services';
import { UiDropdownMenuComponent } from '../ui-dropdown-menu';
import { UiComplexDropdownSelectedValue } from './ui-complex-dropdown.model';
import * as i0 from "@angular/core";
/**
 * # Complex dropdown component
 *
 * Complex Dropdown allows user to search and select a value from given set of options.
 *
 * ## Component variations
 *
 * - Contained (on light)
 * - Uncontained (on light)
 * - Disabled
 * - Readonly
 * - Invalid
 * - Required
 *
 * ## Content
 *
 * The content of the complex dropdown component can be any valid markup.
 *
 * ## Code example
 * @example ```html
 * <sie-ui-complex-dropdown
 *  [confirmButtonDisabled]="true"
 *  [resetButtonDisabled]="true"
 *  [confirmButtonDesc]="'Confirm'"
 *  [resetButtonDesc]="'Reset'"
 *  [clearInputEnabled]="true"
 *  [placeholder]="'Placeholder'"
 *  [theme]="'light'"
 *  [type]="'un-contained'"
 * >
 *  <sie-ui-richtext contentSlot [content]="'<h1>Hello world!</h1> <p>Lorem ipsum...</p>'"></sie-ui-richtext>
 * </sie-ui-complex-dropdown>
 * ```
 */
export declare class UiComplexDropdownComponent<T extends UiComplexDropdownSelectedValue> extends UiDropdownComponent implements OnInit {
    protected cdkOverlayService: CdkOverlayService;
    complexDropdownMenu: UiDropdownMenuComponent;
    complexDropdownMenuContent: ElementRef;
    private _valueSelected;
    private _confirmButtonDisabled;
    private _resetButtonDisabled;
    get resetButtonDisabled(): boolean;
    /**
     * Defines if the reset button is disabled.
     * @default true
     */
    set resetButtonDisabled(value: boolean);
    get confirmButtonDisabled(): boolean;
    /**
     * Defines if the confirm button is disabled.
     * @default true
     */
    set confirmButtonDisabled(value: boolean);
    confirmButtonDesc: string;
    /**
     * Defines the text on the reset button.
     */
    resetButtonDesc: string;
    /**
     * Defines the {@link DropdownType type} of complex dropdown.
     * @default 'contained'
     */
    type: DropdownType;
    /**
     * Event triggered when the confirmation button is clicked.
     */
    confirmEvent: EventEmitter<void>;
    /**
     * Event triggered when the reset button is clicked.
     */
    resetEvent: EventEmitter<void>;
    /** @ignore */
    onFocusAndClick(event: FocusEvent): void;
    constructor(iconReg: SieIconRegistryService, elementRef: ElementRef, cdr: ChangeDetectorRef, layoutService: LayoutService, eventPropagationService: UiEventPropagationService, cdkOverlayService: CdkOverlayService);
    /**
     * @param value Defines the value that is selected in the complex dropdown menu.
     */
    set valueSelected(value: T);
    get valueSelected(): T;
    /**
     * Confirms the selected value in the complex dropdown menu.
     */
    confirm(event?: KeyboardEvent): void;
    /**
     * Resets the selected value in the complex dropdown menu.
     */
    reset(): void;
    /** @ignore */
    focusOverlayContent(event: KeyboardEvent): void;
    /** @ignore */
    onFocusIn(): void;
    /** Closes the overlay when the complex dropdown is focused out.  */
    onFocusOut(): void;
    /** @ignore */
    onClose(event: KeyboardEvent): void;
    /** @ignore */
    onResetButtonClicked(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiComplexDropdownComponent<any>, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiComplexDropdownComponent<any>, "sie-ui-complex-dropdown", never, { "resetButtonDisabled": { "alias": "resetButtonDisabled"; "required": false; }; "confirmButtonDisabled": { "alias": "confirmButtonDisabled"; "required": false; }; "confirmButtonDesc": { "alias": "confirmButtonDesc"; "required": false; }; "resetButtonDesc": { "alias": "resetButtonDesc"; "required": false; }; "type": { "alias": "type"; "required": false; }; "valueSelected": { "alias": "valueSelected"; "required": false; }; }, { "confirmEvent": "confirmEvent"; "resetEvent": "resetEvent"; }, never, ["[contentSlot]", "[actionButton]"], false, never>;
}
//# sourceMappingURL=ui-complex-dropdown.component.d.ts.map