import { AfterViewInit, ChangeDetectorRef, ElementRef, OnChanges, OnInit, SimpleChanges } from '@angular/core';
import { UiDatePickerOverlay } from '../overlay/ui-date-picker-overlay';
import { MatCalendar, MatDatepicker, MatDateRangePicker } from '@angular/material/datepicker';
import { Subscription } from 'rxjs';
import { DateFormatService, DateParserService, LayoutService, TimerType } from '@siemens/core';
import { DateAdapter } from '@angular/material/core';
import { NgFormControlDirective } from '../../ui-form-control/ui-ng-form-control.directive';
import { AbstractControl, ValidationErrors } from '@angular/forms';
import { UiEventPropagationService } from '../../services/ui-event-propagation.service';
import * as i0 from "@angular/core";
export declare enum DatePickerValidity {
    Valid = 0,
    RequiredError = 1,
    InvalidDateError = 2,
    RangeError = 3,
    EndDateError = 4,
    CustomFilterError = 5,
    CustomFilterStartDateError = 6,
    CustomFilterEndDateError = 7,
    CustomFilterRangeError = 8
}
export declare abstract class UiDatePickerBaseDirective<DP extends MatDatepicker<Date> | MatDateRangePicker<Date>> extends NgFormControlDirective implements AfterViewInit, OnInit, OnChanges {
    protected dateParser: DateParserService;
    protected dateFormatService: DateFormatService;
    protected readonly layoutService: LayoutService;
    protected cdr: ChangeDetectorRef;
    protected dateAdapter: DateAdapter<Date>;
    readonly eventPropagationService: UiEventPropagationService;
    private _locale;
    get locale(): string;
    set locale(value: string);
    label: string;
    private _required;
    get required(): boolean;
    set required(value: boolean);
    touchUiModeActive: boolean;
    set minDate(minDate: Date);
    get minDate(): Date;
    set maxDate(maxDate: Date);
    get maxDate(): Date;
    customDateFilter: (date?: Date) => boolean;
    requiredErrorMessage: string;
    invalidDateErrorMessage: string;
    rangeErrorMessage: string;
    protected _disabled: boolean;
    protected _minDate: Date;
    protected _maxDate: Date;
    get disabled(): boolean;
    set disabled(value: boolean);
    get inputFieldFocused(): boolean;
    get isInvalid(): boolean;
    pickerWrapper: ElementRef;
    abstract datepicker: DP;
    protected dateFormat: any;
    protected focusTimeout: TimerType;
    protected outsideClickSub: Subscription;
    protected allowedFormats: any[];
    protected validityState: DatePickerValidity;
    protected errorMessages: string[];
    protected keyboardNavActive: boolean;
    protected _error: string;
    protected _inputFieldFocused: boolean;
    get defaultMinDate(): Date;
    get defaultMaxDate(): Date;
    get error(): string;
    protected constructor(dateParser: DateParserService, dateFormatService: DateFormatService, layoutService: LayoutService, cdr: ChangeDetectorRef, dateAdapter: DateAdapter<Date>, eventPropagationService: UiEventPropagationService);
    ngAfterViewInit(): void;
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    onInputFieldKeyup(event: KeyboardEvent): void;
    validateDate(): void;
    abstract onCalendarOpen(): void;
    abstract onCalendarClose(): void;
    abstract focusInputField(): void;
    abstract onFieldBlur(event: Event): void;
    protected abstract isValidRequired(): boolean;
    protected abstract hasValidValue(): boolean;
    protected abstract isValidRange(): boolean;
    protected onLocaleUpdatedBase(): void;
    protected abstract onLocaleUpdated(): any;
    protected setValidity(validity: DatePickerValidity): void;
    protected condition(testCondition: boolean, error: DatePickerValidity): DatePickerValidity;
    protected activateKeyboardNav(): void;
    protected deactivateKeyboardNav(): void;
    protected getOverlay(): UiDatePickerOverlay<unknown>;
    protected getCalendar(): MatCalendar<unknown>;
    protected subscribeToBackdropClick(): Subscription;
    protected focusField(fieldRef: ElementRef): void;
    private populateErrorMessages;
    protected formatDate(date: Date): string;
    protected initializeDateFormat(): void;
    private assignCssWidthVariable;
    validateInternal(control: AbstractControl): ValidationErrors | null;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiDatePickerBaseDirective<any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<UiDatePickerBaseDirective<any>, "[sieUiDatePickerBase]", never, { "locale": { "alias": "locale"; "required": false; }; "label": { "alias": "label"; "required": false; }; "required": { "alias": "required"; "required": false; }; "minDate": { "alias": "minDate"; "required": false; }; "maxDate": { "alias": "maxDate"; "required": false; }; "customDateFilter": { "alias": "customDateFilter"; "required": false; }; "requiredErrorMessage": { "alias": "requiredErrorMessage"; "required": false; }; "invalidDateErrorMessage": { "alias": "invalidDateErrorMessage"; "required": false; }; "rangeErrorMessage": { "alias": "rangeErrorMessage"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; }, {}, never, never, false, never>;
}
//# sourceMappingURL=ui-date-picker-base.directive.d.ts.map