import { ElementRef, OnInit } from '@angular/core';
import { UiDonatSegment, UiDonutChartVariant, UiDonutPartial } from '.';
import * as i0 from "@angular/core";
/**
 * # Donut Chart Component
 *
 * The Donut Chart component is used to visualize proportions of categorical data.
 *
 * ## Component variations
 *
 * - distribution (displays only secondary label)
 * - progress (displays primary and secondary label)
 *
 * ## Content
 *
 * The Donut Chart component does not accept any content.
 *
 * ## Code example
 * @example
 * Template:
 * ```html
 * <sie-ui-donut-chart
 *    variant="progress"
 *    [primaryLabel]="2000/4000"
 *    [secondaryLabel]="Parts used"
 *    [partials]="partialsData">
 *</sie-ui-donut-chart>
 * <sie-ui-donut-chart
 *    variant="distribution"
 *    [secondaryLabel]="Article availability"
 *    [partials]="partialsData">
 * </sie-ui-donut-chart>
 * <sie-ui-donut-chart
 *    variant="distribution"
 *    size="200px"
 *    strokeWidth="30px"
 *    [secondaryLabel]="Article availability"
 *    [partials]="partialsData">
 * </sie-ui-donut-chart>
 * ```
 *
 * Partials data example:
 * ``` js
 * const partialsData = [
 *  {
 *    percentage: 50,
 *    color: 'orange'
 *  }
 * ];
 * ```
 */
export declare class UiDonutChartComponent implements OnInit {
    /** @ignore */
    readonly MIN_NUMBER_OF_LINES_TO_SHOW = 2;
    /** @ignore */
    readonly MAX_NUMBER_OF_LINES_TO_SHOW = 3;
    /** @ignore */
    showPrimaryLabel: boolean;
    /** @ignore */
    donutChart: ElementRef;
    /**
     * Defines {@link UiDonutChartVariant variant} in which variant the Donut Chart component will be shown.
     * @default 'distribution'
     */
    variant: UiDonutChartVariant;
    /**
     * Defines text used as primary label in Donut Chart component.
     * @default ''
     */
    primaryLabel: string;
    /**
     * Defines text used as secondary label in Donut Chart component.
     * @default ''
     */
    secondaryLabel: string;
    /**
     * Defines the partials {@link UiDonutPartial} data of the Donut Chart component.
     */
    partials: UiDonutPartial[];
    /**
     * Defines the size of Donut Chart component.
     * @default '180px'
     */
    size: string;
    /**
     * Defines the stroke width of Donut Chart component.
     * @default '24px'
     */
    strokeWidth: string;
    /** @ignore */
    get segments(): UiDonatSegment[];
    private _segments;
    /** @ignore */
    get radiusAttribute(): string;
    private _radiusAttribute;
    private radius;
    private circumference;
    private svgPercent;
    /** @ignore */
    ngOnInit(): void;
    private updateSizes;
    private mapSegments;
    private getSvgPercentage;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiDonutChartComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiDonutChartComponent, "sie-ui-donut-chart", never, { "variant": { "alias": "variant"; "required": false; }; "primaryLabel": { "alias": "primaryLabel"; "required": false; }; "secondaryLabel": { "alias": "secondaryLabel"; "required": false; }; "partials": { "alias": "partials"; "required": false; }; "size": { "alias": "size"; "required": false; }; "strokeWidth": { "alias": "strokeWidth"; "required": false; }; }, {}, never, never, false, never>;
}
//# sourceMappingURL=ui-donut-chart.component.d.ts.map