import { ElementRef, EventEmitter } from '@angular/core';
import { ThemeVariant } from '@siemens/core';
import { SieIconRegistryService } from '@siemens/icons';
import { UiDropdownMenuModel, UiDropdownOptionType, UiDropdownSelectionType } from '../ui-dropdown-menu/ui-dropdown-menu.model';
import { PointerDeviceService } from '../services/pointer-device.service';
import * as i0 from "@angular/core";
/**
 * # Dropdown options component
 * Defines options which are displayed in the {@link UiDropdownMenuComponent } and cannot be used separately.
 */
export declare class UiDropdownOptionsComponent {
    readonly elementRef: ElementRef;
    readonly iconReg: SieIconRegistryService;
    get options(): UiDropdownMenuModel[];
    /**
     * @param value array of options {@link UiDropdownMenuModel}
     */
    set options(value: UiDropdownMenuModel[]);
    /**
     * Defines the dropdown option {@link ThemeVariant theme}
     * @default 'light'
     */
    theme: ThemeVariant;
    /**
     * Defines the style of the menu {@link UiDropdownSelectionType selectionType}
     * @default 'single'
     */
    selectionType: UiDropdownSelectionType;
    /**
     * Selected {@link UiDropdownMenuModel dropdown options} values
     */
    selectedValues: string[];
    /**
     * @param value adds spacing to icon styling if value is true
     * @default false
     */
    set displayIconSpace(value: boolean);
    get displayIconSpace(): boolean;
    /**
     * Defines dropdown options type {@link UiDropdownOptionType}
     * @default 'menu'
     */
    type: UiDropdownOptionType;
    /**
     * Adds styling for disabled checkmark if set to true
     * @default false
     */
    checkmarkDisabled: boolean;
    /**
     * Defines if overlay is open or closed
     * @default false
     */
    open: boolean;
    /**
     * Aria label for dropdown option
     * @default ''
     */
    ariaLabel: string;
    /**
     * Event triggered when an option in dropdown is selected {@link UiDropdownMenuModel}, please update {@link selectedValues} after processing the event
     */
    optionSelected: EventEmitter<UiDropdownMenuModel>;
    /**
     * Event triggered when an option is discarded
     */
    optionDiscarded: EventEmitter<void>;
    /** @ignore */
    readonly maxSizeForScrollbar = 9;
    private _options;
    private _displayIconSpace;
    private _selectionIndex;
    readonly avoidPointerDownCollision: typeof PointerDeviceService.avoidPointerDownCollision;
    constructor(elementRef: ElementRef, iconReg: SieIconRegistryService);
    /** @ignore */
    isDisabled(index: number): boolean;
    /** @ignore */
    onArrowHandler(e: KeyboardEvent): void;
    /**
     * Method to check whether element is focused or not
     * @returns boolean if focused or not
     */
    isElementFocused(): boolean;
    /** @ignore */
    itemSelected(event: Event, selectedItem: UiDropdownMenuModel): void;
    /** @ignore */
    handleEscapeDown(event: KeyboardEvent): void;
    private focusElement;
    private registerIconsFromOptions;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiDropdownOptionsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiDropdownOptionsComponent, "sie-ui-dropdown-options", never, { "options": { "alias": "options"; "required": false; }; "theme": { "alias": "theme"; "required": false; }; "selectionType": { "alias": "selectionType"; "required": false; }; "selectedValues": { "alias": "selectedValues"; "required": false; }; "displayIconSpace": { "alias": "displayIconSpace"; "required": false; }; "type": { "alias": "type"; "required": false; }; "checkmarkDisabled": { "alias": "checkmarkDisabled"; "required": false; }; "open": { "alias": "open"; "required": false; }; "ariaLabel": { "alias": "ariaLabel"; "required": false; }; }, { "optionSelected": "optionSelected"; "optionDiscarded": "optionDiscarded"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-dropdown-options.component.d.ts.map