import { ChangeDetectorRef, ElementRef, EventEmitter } from '@angular/core';
import { ThemeVariant, TimerType } from '@siemens/core';
import { UiDropdownMenuModel } from '../../ui-dropdown-menu/ui-dropdown-menu.model';
import { UiDropdownMenuComponent } from '../../ui-dropdown-menu/ui-dropdown-menu.component';
import { UiEventPropagationService } from '../../services/ui-event-propagation.service';
import { CdkOverlayService } from '../../services/cdk-overlay.service';
import { Subject } from 'rxjs';
import * as i0 from "@angular/core";
/**
 * Overlay offset for uncontained dropdown flyout.
 */
export declare const CDK_OVERLAY_OFFSET_X = -16;
/**
 * This directive is used to handle data and display parameters for the ui-dropdown component.
 */
export declare abstract class UiDropdownBaseDirective<T extends UiDropdownMenuModel, DE = ElementRef> {
    protected cdr: ChangeDetectorRef;
    protected elementRef: ElementRef;
    readonly eventPropagationService: UiEventPropagationService;
    protected cdkOverlayService: CdkOverlayService;
    /** @ignore */
    dropDownRendering: ElementRef;
    /** @ignore */
    dropDownElement: DE;
    /** @ignore */
    dropDownMenu: UiDropdownMenuComponent;
    /**
     * @param value Defines content of each dropdown item option.
     */
    set options(value: T[]);
    get options(): T[];
    protected _options: T[];
    /**
     * @param value Sets the disabled state to the dropdown.
     * @default false
     */
    set disabled(value: boolean);
    get disabled(): boolean;
    protected _disabled: boolean;
    /**
     * Defines the {@link ThemeVariant Mode} of the component.
     * @default 'light'
     */
    theme: ThemeVariant;
    /**
     * Defines the screen reader text for the dropdown.
     */
    screenReaderText?: string;
    /**
     * @param value enables reset icon styles and functionality
     * @default false
     */
    set clearInputEnabled(value: boolean);
    get clearInputEnabled(): boolean;
    /**
     * Defines the text used by screen readers for the reset icon
     * @default '' (empty string)
     */
    clearInputIconScreenReaderText: string;
    /**
     * Sets the dropdown overlay in top position.
     */
    set overlayOnTop(value: boolean);
    get overlayOnTop(): boolean;
    protected _overlayOnTop?: boolean;
    /**
     * @param value Sets the space in front of the input text.
     */
    set displayIconSpace(value: boolean);
    get displayIconSpace(): boolean;
    /** @ignore */
    get menuOpen(): boolean;
    /** @ignore */
    set menuOpen(value: boolean);
    /**
     * Event triggered when the dropdown menu is opened
     */
    dropdownMenuOpened: Subject<boolean>;
    /**
     * Event triggered when the reset input icon is clicked.
     */
    clearInput: EventEmitter<void>;
    protected _displayIconSpace: boolean;
    protected focusOutTimer: TimerType;
    protected _clearInput: boolean;
    /** @ignore */
    menuPositionedBottom: boolean;
    /** @ignore */
    dropdownWidth: number;
    /** @ignore */
    overlayPaneHeight: number;
    private _menuOpen;
    protected constructor(cdr: ChangeDetectorRef, elementRef: ElementRef, eventPropagationService: UiEventPropagationService, cdkOverlayService: CdkOverlayService);
    /** @ignore */
    focusIn(): void;
    /** @ignore */
    focusOut(): void;
    /** @ignore */
    handleEscape(event: KeyboardEvent): void;
    /** Closes the dropdown overlay. */
    closeOverlay(focusDropdownButton?: boolean): void;
    /** @ignore */
    toggleDropDown(event?: KeyboardEvent): void;
    /** Opens the dropdown overlay. */
    openOverlay(): void;
    private calculateOverlayPaneWidth;
    private calculateOverlayPaneHeight;
    /** @ignore */
    recalculatePositions(): void;
    /** @ignore */
    onArrowDownOnButton(event: KeyboardEvent): void;
    /** @param index Focuses the dropdown item. */
    focusElement(index: number): void;
    /** @ignore */
    isDisabled(index: number): boolean;
    onResetButtonClicked(selector: string): void;
    protected focusInputField(selector: string): void;
    protected determineVerticalMenuAlignment(): void;
    private calculateVerticalMenuAlignment;
    protected abstract determineHorizontalMenuAlignment(): void;
    abstract itemSelected(selectedItem: T): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiDropdownBaseDirective<any, any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<UiDropdownBaseDirective<any, any>, never, never, { "options": { "alias": "options"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "theme": { "alias": "theme"; "required": false; }; "screenReaderText": { "alias": "screenReaderText"; "required": false; }; "clearInputEnabled": { "alias": "clearInputEnabled"; "required": false; }; "clearInputIconScreenReaderText": { "alias": "clearInputIconScreenReaderText"; "required": false; }; "overlayOnTop": { "alias": "overlayOnTop"; "required": false; }; "displayIconSpace": { "alias": "displayIconSpace"; "required": false; }; }, { "dropdownMenuOpened": "dropdownMenuOpened"; "clearInput": "clearInput"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-dropdown.base.directive.d.ts.map