import { SieIcon } from '@siemens/icons';
import { LinkModel } from '../ui-link/ui-link.model';
import { UiButtonModel } from '../ui-button/base/ui-button.model';
/**
 * Variant types for empty state:
 * - `small` (depending on the breakpoint)
 * - `regular`
 */
export type EmptyStateVariant = 'small' | 'regular';
/**
 * Position type for empty state icon:
 * - `onTop` icon is positioned above the headline
 * - `inFrontOfHeadline` icon is positioned before the headline
 */
export type EmptyStateIconPosition = 'onTop' | 'inFrontOfHeadline';
export interface EmptyStateModel {
    /**
     * {@link EmptyStateVariant Variant} of empty state
     */
    variant?: EmptyStateVariant;
    /**
     * Headline of empty state
     */
    headline?: string;
    /**
     * Text of empty state
     */
    text?: string;
    /**
     * {@link SieIcon Icon} of empty state
     */
    customIcon: SieIcon;
    /**
     * {@link EmptyStateIconPosition position} of the icon in empty state
     */
    iconPosition?: EmptyStateIconPosition;
    /**
     * {@link LinkModel Link} in empty state
     */
    link?: LinkModel;
    /**
     * {@link UiButtonModel Button} in empty state
     */
    button?: UiButtonModel;
    /** @ignore */
    translationKey?: string;
}
//# sourceMappingURL=ui-empty-state.model.d.ts.map