import { ThemeVariant } from '@siemens/core';
import { HintModel } from '../shared/models/hint.model';
import { FormControl } from './ui-form.control';
import * as i0 from "@angular/core";
/**
 * Base class to be derived from form controls to inherit common used attributes
 */
export declare class FormControlDirective implements FormControl {
    /**
     * {@link ThemeVariant Theme} of the component
     * @default 'light'
     */
    theme: ThemeVariant;
    /**
     * Identifier used to distinguish the component from others
     */
    id?: string;
    /**
     * Name of the component
     */
    name?: string;
    /**
     * Label of the component
     */
    label: string;
    /**
     * Placeholder for the component
     */
    placeholder: string;
    /**
     * Message displayed when component state is invalid
     */
    errorMessage: string;
    /**
     * Used to add custom css classes to the component
     * @default '' empty string (does not apply any styles)
     */
    customClass: string;
    /**
     * @param value Removes functionality (click events, expanding capability) from the component and changes heading
     * color when set to true
     * @default false
     */
    set disabled(value: boolean);
    get disabled(): boolean;
    /**
     * @param value Sets state of the component as readonly
     * @default false
     */
    set readonly(value: boolean);
    get readonly(): boolean;
    /**
     * @param value Sets state of the component as invalid and adds style changes
     * @default false
     */
    set invalid(value: boolean);
    get invalid(): boolean;
    /**
     * @param hint Defines the {@link HintModel hint } on the element
     */
    set hint(hint: HintModel);
    get hint(): HintModel;
    protected _disabled: boolean;
    protected _readonly: boolean;
    protected _invalid: boolean;
    protected _hint: HintModel;
    static ɵfac: i0.ɵɵFactoryDeclaration<FormControlDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<FormControlDirective, never, never, { "theme": { "alias": "theme"; "required": false; }; "id": { "alias": "id"; "required": false; }; "name": { "alias": "name"; "required": false; }; "label": { "alias": "label"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; "errorMessage": { "alias": "errorMessage"; "required": false; }; "customClass": { "alias": "customClass"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "readonly": { "alias": "readonly"; "required": false; }; "invalid": { "alias": "invalid"; "required": false; }; "hint": { "alias": "hint"; "required": false; }; }, {}, never, never, false, never>;
}
/** @ignore */
export declare const setDefaultsForHint: (hint: HintModel) => void;
//# sourceMappingURL=ui-form-control.directive.d.ts.map