import { AbstractControl, ControlValueAccessor, ValidationErrors, Validator } from '@angular/forms';
import { FormControlDirective } from './ui-form-control.directive';
import * as i0 from "@angular/core";
/**
 * Base class to be derived from form controls to inherit attributes from {@link FormControlDirective} and
 * Angular form control default behaviour.
 */
export declare abstract class NgFormControlDirective extends FormControlDirective implements ControlValueAccessor, Validator {
    /**
     * Helper variable to store if the control has been touched
     */
    touched: boolean;
    /**
     * Used from derived component to report that internal state/value has changed
     */
    onChange: (value: any) => void;
    /**
     * Used from derived component to report that control has been touched
     */
    onTouched: () => void;
    /**
     * Used from derived component to report that validator has been changed
     */
    onValidatorChanged: () => void;
    /**
     * Method to be implemented allowing Angular's FormModule two-way binding the control
     * @param obj value to be set
     */
    abstract writeValue(obj: any): void;
    /**
     * Method to implement the component's validation
     *
     * @param control Concrete access to {@link AbstractControl form control object}
     */
    abstract validateInternal(control: AbstractControl): ValidationErrors | null;
    /**
     * Concrete implementation of {@link ControlValueAccessor ControlValueAccessor.registerOnChange} method allowing
     * changing `onChange` function
     * @param fn callback function
     */
    registerOnChange(fn: any): void;
    /**
     * Concrete implementation of {@link ControlValueAccessor ControlValueAccessor.registerOnTouched} method allowing
     * changing `onTouched` function
     * @param fn callback function
     */
    registerOnTouched(fn: any): void;
    /**
     * Concrete implementation of {@link ControlValueAccessor ControlValueAccessor.setDisabledState} method allowing
     * setting/removing the component's disabled state
     * @param disabled whether the component shall be enabled or disabled
     */
    setDisabledState(disabled: boolean): void;
    /**
     * Helper method to mark that component has been touched
     */
    markAsTouched(): void;
    /**
     * Concrete implementation of {@link ControlValueAccessor ControlValueAccessor.registerOnValidatorChange} method
     * allowing changing `onValidatorChanged` function
     * @param fn callback function
     */
    registerOnValidatorChange(fn: () => void): void;
    /**
     * Concrete implementation that wraps abstract `validateInternal` method
     * @param control Concrete access to {@link AbstractControl form control object}
     * @return checkout {@link Validator}
     */
    validate(control: AbstractControl): ValidationErrors | null;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgFormControlDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<NgFormControlDirective, never, never, {}, {}, never, never, false, never>;
}
//# sourceMappingURL=ui-ng-form-control.directive.d.ts.map