import { EventEmitter } from '@angular/core';
import { ThemeVariant } from '@siemens/core';
import { SieIcon, SieIconRegistryService } from '@siemens/icons';
import * as i0 from "@angular/core";
/**
 * # Icon Button component
 *
 * Icon Buttons are used to trigger some kind of action such as submitting, deleting, showing or hiding the content.
 *
 * ## Component variations
 *
 * Button type: 'button'
 *
 * ## Content
 *
 * The Icon Button component does not accept any content.
 *
 * ## Code example
 * @example ```html
 * <sie-ui-icon-button
 *  [theme]="'dark'"
 *  [disabled]="true"
 *  [icon]="'ShoppingCart'"
 *  [iconScreenReaderText]="'Shopping cart icon'"
 * ></sie-ui-icon-button>
 * ```
 */
export declare class UiIconButtonComponent {
    readonly iconReg: SieIconRegistryService;
    /**
     * Defines {@link ThemeVariant Variant} theme
     * @default 'light'
     */
    theme: ThemeVariant;
    /**
     * Defines if icon-button is displayed in disable state
     * @default false
     */
    disabled: boolean;
    /**
     * Defines for the hover state whether coloured styling should be applied
     * @default false
     */
    hoverColored: boolean;
    /**
     * Sets the screen reader text for the icon
     */
    iconScreenReaderText: string;
    /**
     * @param icon Defines which {@link SieIcon icon} should be displayed inside the button.
     * @default SieIcon.CloseSmall close icon
     */
    set icon(icon: SieIcon);
    get icon(): SieIcon;
    /**
     * Event triggered when the button is clicked.
     */
    clicked: EventEmitter<MouseEvent>;
    private _icon;
    constructor(iconReg: SieIconRegistryService);
    static ɵfac: i0.ɵɵFactoryDeclaration<UiIconButtonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiIconButtonComponent, "sie-ui-icon-button", never, { "theme": { "alias": "theme"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "hoverColored": { "alias": "hoverColored"; "required": false; }; "iconScreenReaderText": { "alias": "iconScreenReaderText"; "required": false; }; "icon": { "alias": "icon"; "required": false; }; }, { "clicked": "clicked"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-icon-button.component.d.ts.map