import { SieIcon } from '@siemens/icons';
import { PlainObject } from '@siemens/core';
export type LinkVariant = 'icon-link' | 'inline';
export type LinkBackground = 'light' | 'dark' | 'dark-alt' | 'dark-white' | 'light-neutral' | 'dark-neutral';
export type LinkType = 'link' | 'button';
export type LinkSize = '' | 'sm' | 'xs' | 'xxs';
export interface LinkModel {
    /**
     * Sets the custom css class on anchor element.
     * To add multiple classes provide the string with the whitespace between classes, e.g.: `class-a class-b`.
     */
    cssClass?: string;
    /**
     * Sets the URL that the link redirects you to.
     */
    href: string;
    /**
     * Defines the {@link LinkSize size} of the link.
     */
    size?: LinkSize;
    /**
     * Defines if the link is disabled.
     */
    disabled?: boolean;
    /**
     * Defines the text of the link.
     */
    linkText: string;
    /**
     * Defines which {@link SieIcon icon} should be shown inside the link.
     * If not provided, the `ArrowRight` icon is used by default
     */
    icon?: SieIcon;
    /**
     * Defines where the link should be opened.
     */
    target?: string;
    /**
     * Defines the {@link LinkVariant variation} of the link.
     */
    variant?: LinkVariant;
    /**
     * Defines a secondary label for a link variant `icon-link`, normally used with `light-neutral`, `dark-neutral` background type.
     */
    secondaryLabel?: string;
    /**
     * Defines on which {@link LinkBackground background} the link is placed.
     */
    background?: LinkBackground;
    /**
     * Defines the actual {@link LinkType type} of HTML element.
     */
    type?: LinkType;
    /**
     * Defines the identification of the link.
     */
    id?: string;
    /**
     * Add additional attributes to the link component (e.g.: for tracking).
     */
    dataAttributes?: PlainObject;
    /**
     * Defines the {@link SieIcon icon} in the trailing position.
     */
    trailingIcon?: SieIcon;
}
//# sourceMappingURL=ui-link.model.d.ts.map