import { UiDynamicListItemComponent } from './ui-dynamic-list-item/ui-dynamic-list-item.component';
import { ChangeDetectorRef, QueryList, Type } from '@angular/core';
import { UIListItemAppearance, UIListItemType } from './ui-list.types';
import { Subject, Observable } from 'rxjs';
import { UiAdvancedListItemSelectionChangeData, UiListItemEvent } from './ui-list-item/ui-list-item.directive';
import { PaginationType } from '../ui-list-navigator/ui-list-navigator-inputs';
import { UiListItemModel } from './ui-list-item/ui-list-item.model';
import * as i0 from "@angular/core";
/**
 * # List Component
 *
 * The component is only used within the {@link UiListNavigatorComponent}.
 */
export declare class UiListComponent {
    protected cdr: ChangeDetectorRef;
    /**
     * Defines default component type for list items
     */
    defaultItemComponents: Type<any>[];
    /**
     * Defines data of each list item
     */
    itemData: UiListItemModel[];
    /**
     * Defines if bulk mode is used
     * @default false
     */
    bulkMode: boolean;
    /**
     * Allows items to be dismissed when set to true
     * @default false
     */
    itemsDismissible: boolean;
    isSelected$: Observable<Array<string>>;
    /**
     * Defines list item type {@link UIListItemType}
     * @default 'folder'
     */
    itemType: UIListItemType;
    /**
     * Defines appearance of list item {@link UIListItemAppearance}
     * @default 'simple'
     */
    itemAppearance: UIListItemAppearance;
    /**
     * Manages styling with less padding and margin
     * @default false
     */
    condensed: boolean;
    /**
     * Total of list items
     */
    itemLength: number;
    /**
     * Displays loading state of list items if set to true
     * @default true
     */
    loading: boolean;
    /** @ignore */
    loadingChildren: boolean;
    /**
     * Defines if more list items are being loaded (used in infinite pagination style)
     * @default false
     */
    loadingMore: boolean;
    /**
     * Defines if hover should be tracked and hover styles applied on the list items
     * @default false
     */
    trackHover: boolean;
    /**
     * Defines if status indicator is displayed
     * @default true
     */
    showStatusIndicator: boolean;
    /**
     * Defines if only selected items will be displayed in print preview, does nothing when not in bulk-selection mode
     * @default false
     */
    hideNotSelectedItemsInPrintPreview: boolean;
    /**
     * Defines how many skeleton elements should be displayed
     * @default 5
     */
    numberOfSkeletons: number;
    /**
     * Defines how many skeleton elements should be displayed in case of infinite pagination
     * @default 3
     */
    numberOfLoadMoreSkeletons: number;
    /**
     * Text for show more button of list item
     * @default ''
     */
    expandableButtonMore: string;
    /**
     * Text for show less button of list item
     * @default ''
     */
    expandableButtonLess: string;
    /**
     * Defines what pagination type should be used if pagination is needed
     * @default 'default'
     */
    paginationType: PaginationType;
    /** @ignore */
    showCatalogConfigureProducts: boolean;
    /**
     * Triggered when user interaction is done, see {@link UiListItemEvent} for implementation details
     */
    itemEvent: Subject<UiListItemEvent<unknown, import("@siemens/core").PlainObject>>;
    /**
     * Triggered when component is in bulk mode and a new item was selected {@link UiAdvancedListItemSelectionChangeData}
     */
    selectionChanged: Subject<UiAdvancedListItemSelectionChangeData>;
    /** @ignore */
    dynamicListItemsComponents: QueryList<UiDynamicListItemComponent>;
    constructor(cdr: ChangeDetectorRef);
    /** @ignore */
    updateView(): void;
    /** @ignore */
    itemIntersected(isVisible: boolean): void;
    trackById(_: any, item: UiListItemModel): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiListComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiListComponent, "ul[sie-ui-list]", never, { "defaultItemComponents": { "alias": "defaultItemComponents"; "required": false; }; "itemData": { "alias": "itemData"; "required": false; }; "bulkMode": { "alias": "bulkMode"; "required": false; }; "itemsDismissible": { "alias": "itemsDismissible"; "required": false; }; "isSelected$": { "alias": "isSelected$"; "required": false; }; "itemType": { "alias": "itemType"; "required": false; }; "itemAppearance": { "alias": "itemAppearance"; "required": false; }; "condensed": { "alias": "condensed"; "required": false; }; "itemLength": { "alias": "itemLength"; "required": false; }; "loading": { "alias": "loading"; "required": false; }; "loadingChildren": { "alias": "loadingChildren"; "required": false; }; "loadingMore": { "alias": "loadingMore"; "required": false; }; "trackHover": { "alias": "trackHover"; "required": false; }; "showStatusIndicator": { "alias": "showStatusIndicator"; "required": false; }; "hideNotSelectedItemsInPrintPreview": { "alias": "hideNotSelectedItemsInPrintPreview"; "required": false; }; "numberOfSkeletons": { "alias": "numberOfSkeletons"; "required": false; }; "numberOfLoadMoreSkeletons": { "alias": "numberOfLoadMoreSkeletons"; "required": false; }; "expandableButtonMore": { "alias": "expandableButtonMore"; "required": false; }; "expandableButtonLess": { "alias": "expandableButtonLess"; "required": false; }; "paginationType": { "alias": "paginationType"; "required": false; }; "showCatalogConfigureProducts": { "alias": "showCatalogConfigureProducts"; "required": false; }; }, { "itemEvent": "itemEvent"; "selectionChanged": "selectionChanged"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-list.component.d.ts.map