import { AfterViewInit, ChangeDetectorRef } from '@angular/core';
import { SieIconRegistryService } from '@siemens/icons';
import { UiButtonClickModel } from '../../ui-button';
import { UiButtonGroupComponent } from '../../ui-button-group/ui-button-group.component';
import { UiConfirmationModalBaseDirective } from '../ui-confirmation-modal.base.directive';
import { UiModalComponentService } from '../ui-modal-component.service';
import { UiConfirmationModalModel } from '../ui-modal.model';
import { UiModalComponent } from '../ui-modal/ui-modal.component';
import * as i0 from "@angular/core";
/**
 * # Confirmation Modal component
 *
 * Present critical information to the user or to (re)assure users about a critical action.
 *
 * ## Component variations
 *
 * - Confirmation Modal component that contains a headline mostly used for confirmation and optionally two buttons
 * to ask the user how to proceed.
 *
 * ## Content
 *
 * A confirmation modal does not accept any content.
 *
 * ## Code example
 * @example ```html
 * <sie-ui-confirmation-modal
 *  [data]="{
 *    headline: 'Confirmation',
 *    text: 'Do you really want to delete this item?',
 *    okButton: { text: 'Ok', icon: 'CheckMark' },
 *    cancelButton: { text: 'Abort', icon: 'Close' },
 *    size: 'm',
 *    screenReaderCloseIcon: 'Close'
 *   }"
 * ></sie-ui-confirmation-modal>
 * ```
 */
export declare class UiConfirmationModalComponent extends UiConfirmationModalBaseDirective implements AfterViewInit {
    protected readonly iconReg: SieIconRegistryService;
    private readonly cdr;
    private readonly modalComponentService;
    /** @ignore */
    buttonGroupComponent: UiButtonGroupComponent;
    /** @ignore */
    confirmationModal: UiModalComponent;
    /**
     * @param data Provides {@link UiConfirmationModalModel configuration} on how the
     * confirmationtion modal will look like
     */
    set data(data: UiConfirmationModalModel);
    get data(): UiConfirmationModalModel;
    /**
     * The function that is called when the first/left button is clicked
     */
    okFunction: () => void;
    /**
     * The function that is called when the second/right button is clicked
     */
    cancelFunction: () => void;
    private _data;
    constructor(iconReg: SieIconRegistryService, cdr: ChangeDetectorRef, modalComponentService: UiModalComponentService);
    /** @ignore */
    ngAfterViewInit(): void;
    /** @ignore */
    onButtonClick(event: UiButtonClickModel): void;
    /** @ignore */
    onClose(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiConfirmationModalComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiConfirmationModalComponent, "sie-ui-confirmation-modal", never, { "data": { "alias": "data"; "required": false; }; "okFunction": { "alias": "okFunction"; "required": false; }; "cancelFunction": { "alias": "cancelFunction"; "required": false; }; }, {}, never, never, false, never>;
}
//# sourceMappingURL=ui-confirmation-modal.component.d.ts.map