import { AfterViewInit, ChangeDetectorRef } from '@angular/core';
import { SieIconRegistryService } from '@siemens/icons';
import { UiButtonClickModel } from '../../ui-button';
import { UiConfirmationModalBaseDirective } from '../ui-confirmation-modal.base.directive';
import { UiModalComponentService } from '../ui-modal-component.service';
import { UiLanguageChangeModalModel } from '../ui-modal.model';
import { UiModalComponent } from '../ui-modal/ui-modal.component';
import * as i0 from "@angular/core";
/**
 * # Language Change Modal component
 *
 * Present critical information to the user or to (re)assure users about a critical action.
 *
 * ## Component variations
 *
 * - Language Change Modal component that contains a headline, content and optionally two buttons
 * to ask the user how to proceed.
 *
 * ## Content
 *
 * A language change modal does not accept any content.
 *
 * ## Code example
 * @example ```html
 * <sie-ui-language-change-modal
 *  [data]="{
 *    headline: 'Headline',
 *    text: 'Some text...',
 *    cancelButton: { text: 'Cancel', icon: 'Close' },
 *    size: 'm',
 *    screenReaderCloseIcon: 'Close',
 *    subText: 'Subtext',
 *    links: [
 *      {
 *        id: '1',
 *        label: 'One'
 *      },
 *      {
 *        id: '2',
 *        label: 'Two'
 *      }
 *    ]
 *  }"
 * ></sie-ui-language-change-modal>
 * ```
 */
export declare class UiLanguageChangeModalComponent extends UiConfirmationModalBaseDirective implements AfterViewInit {
    protected readonly iconReg: SieIconRegistryService;
    private readonly cdr;
    private readonly modalComponentService;
    /** @ignore */
    languageChangeModal: UiModalComponent;
    /**
     * @param data Provides {@link UiLanguageChangeModalModel configuration} on how the
     * language change modal will look like
     */
    set data(data: UiLanguageChangeModalModel);
    get data(): UiLanguageChangeModalModel;
    /**
     * @param radioButtonUrlValue The function that is called when the first/left button is clicked
     */
    okFunction: (radioButtonUrlValue: string) => void;
    /**
     * The function that is called when the second/right button is clicked
     */
    cancelFunction: () => void;
    /** @ignore */
    radioButtonUrlValue: string;
    private _data;
    constructor(iconReg: SieIconRegistryService, cdr: ChangeDetectorRef, modalComponentService: UiModalComponentService);
    /** @ignore */
    ngAfterViewInit(): void;
    /** @ignore */
    onButtonClick(event: UiButtonClickModel): void;
    /** @ignore */
    onClose(): void;
    /** @ignore */
    onRadioButtonChanged(id: string): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiLanguageChangeModalComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiLanguageChangeModalComponent, "sie-ui-language-change-modal", never, { "data": { "alias": "data"; "required": false; }; "okFunction": { "alias": "okFunction"; "required": false; }; "cancelFunction": { "alias": "cancelFunction"; "required": false; }; }, {}, never, never, false, never>;
}
//# sourceMappingURL=ui-language-change-modal.component.d.ts.map