import { SieIcon } from '@siemens/icons';
import { UiRadioButtonGroupModel } from '../ui-radio-button-group';
import { ModalSizes } from './ui-modal/ui-modal.component';
/**
 * Different variants for icon shown next to headline
 */
export type UiModalHeadlineVariant = 'info' | 'success' | 'warning' | 'error';
export interface UiConfirmationButtonModel {
    /**
     * Label of the button
     */
    text: string;
    /**
     * Optional {@link SieIcon icon} of the button
     */
    icon?: SieIcon;
}
export interface UiConfirmationModalModel {
    /**
     * Headline of the confirmation modal
     */
    headline: string;
    /**
     * Variant of icon displayed next to the headline
     */
    headlineVariant?: UiModalHeadlineVariant;
    /**
     * Content of the confirmation modal
     */
    text: string;
    /**
     * Definition for the first/left {@link UiConfirmationButtonModel button}
     */
    okButton?: UiConfirmationButtonModel;
    /**
     * Definition for the second/right {@link UiConfirmationButtonModel button}
     */
    cancelButton?: UiConfirmationButtonModel;
    /**
     * {@link ModalSizes Size} of the modal
     */
    size?: ModalSizes;
    /**
     * Screen reader text for the close icon in the header area
     */
    screenReaderCloseIcon: string;
    /**
     * Defines whether the modal should use sticky footer
     */
    stickyFooter?: boolean;
}
export interface UiLanguageChangeModalModel extends UiConfirmationModalModel {
    /**
     * Subcontent below the main content of the language change modal
     */
    subText?: string;
    /**
     * An {@link UiRadioButtonGroupModel array of radio buttons} that are displayed only if two or more are specified
     */
    links?: UiRadioButtonGroupModel;
}
//# sourceMappingURL=ui-modal.model.d.ts.map