import { ChangeDetectorRef, ElementRef, Renderer2, ViewContainerRef } from '@angular/core';
import { UiBaseModalComponent } from '../ui-base-modal.component';
import { LayoutService } from '@siemens/core';
import { SieIconRegistryService } from '@siemens/icons';
import { UiModalComponentService } from '../ui-modal-component.service';
import { CdkOverlayService } from '../../services';
import * as i0 from "@angular/core";
/**
 * # Video Modal component
 *
 * Present critical information to the user or to (re)assure users about a critical action.
 *
 * ## Component variations
 *
 * - Video Modal component that is specially styled to contain video components.
 *
 * ## Content
 *
 * The component can contain child elements. With the right decorator
 * they can be used within the video modal as the following:
 *
 * - `content`: Used as the content within the video modal
 *
 * ## Code example
 * @example ```html
 * <sie-ui-video-modal [backdrop]="false" identifier="videoModal" [closable]="true" [escapable]="true" #videoModal>
 *  <div content>
 *    <sie-ui-video-player
 *      [ratio]="''16-9''"
 *      [size]="'l'"
 *      [video]="{
 *        videoId: '6106650258001',
 *        accountId: '1813624294001',
 *        playerId: 'VMi7Ptd8P',
 *        url: 'https://players.brightcove.net/1813624294001/VMi7Ptd8P_default/index.min.js'
 *      }"
 *      [autoplay]="'true'"
 *      [inModal]="true"
 *    ></sie-ui-video-player>
 *  </div>
 * </sie-ui-video-modal>
 * ```
 */
export declare class UiVideoModalComponent extends UiBaseModalComponent {
    readonly iconReg: SieIconRegistryService;
    protected cdkOverlayService: CdkOverlayService;
    /**
     * Screen reader text for the close icon
     * @default '' empty string
     */
    screenReaderCloseIcon: string;
    constructor(layoutService: LayoutService, modalComponentService: UiModalComponentService, renderer: Renderer2, cdr: ChangeDetectorRef, vcr: ViewContainerRef, elRef: ElementRef, document: Document, _platformId: object, iconReg: SieIconRegistryService, cdkOverlayService: CdkOverlayService);
    /** @ignore */
    onOutsideClick(event: MouseEvent): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiVideoModalComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiVideoModalComponent, "sie-ui-video-modal", never, { "screenReaderCloseIcon": { "alias": "screenReaderCloseIcon"; "required": false; }; }, {}, never, ["[content]"], false, never>;
}
//# sourceMappingURL=ui-video-modal.component.d.ts.map