import { UiOverflowSize } from './ui-overflow.types';
import { AfterViewInit, ChangeDetectorRef, ElementRef, EventEmitter, OnDestroy } from '@angular/core';
import { BreakpointQuery, LayoutService, ThemeVariant } from '@siemens/core';
import { SieIconRegistryService } from '@siemens/icons';
import { Subscription } from 'rxjs';
import { UiOverflowInputs } from './ui-overflow-inputs';
import * as i0 from "@angular/core";
export declare class UiOverflowComponent implements OnDestroy, AfterViewInit, UiOverflowInputs {
    readonly iconReg: SieIconRegistryService;
    private readonly cdr;
    readonly layoutService: LayoutService;
    private readonly elementRef;
    private readonly doc;
    /**
     * @example
     * limit="45px" (pixel value)
     * limit="3" (number of lines of text)
     */
    set limit(value: string);
    forBreakpoints: BreakpointQuery[];
    headlineCollapsed: string;
    headlineExpanded: string;
    useGradient: boolean;
    size: UiOverflowSize;
    buttonIndentationLeft: string;
    buttonIndentationTop: string;
    centered: boolean;
    theme: ThemeVariant;
    useDynamicSubItemHeight: boolean;
    disabled: boolean;
    showExpandButton: boolean;
    gradientColor: string;
    toggled: EventEmitter<boolean>;
    content: ElementRef;
    innerContentWrapper: ElementRef;
    breakpointSubscription: Subscription;
    resizeSubscription$: Subscription;
    isExpandable: boolean;
    lastIsExpandable: boolean;
    isExpanded: boolean;
    lastIsExpanded: boolean;
    maxHeight: number;
    private _limit;
    private viewInitialised;
    private keyBoardActivatedToggle;
    private afterExpandFocusTimeout;
    private innerContent;
    private resizeObserver;
    private mutationObserver;
    constructor(iconReg: SieIconRegistryService, cdr: ChangeDetectorRef, layoutService: LayoutService, elementRef: ElementRef, doc: Document);
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    detectChange(): void;
    toggle(): void;
    onKeyboardToggle(event: KeyboardEvent): void;
    collapse(): void;
    updateElementMaxHeight(): void;
    updateIsExpandable(): void;
    registerImageLoadListeners(): void;
    initialize(): void;
    expand(): void;
    private handleBreakpointChange;
    private subscribeToResize;
    /**
     * This method can be used to re-trigger the overflow mechanism (e.g. content inside  the overflow has changed)
     *
     * @public This is public because external projects could use this method
     */
    handleResize(): void;
    private handleLimitUpdate;
    private unsubscribeFromResize;
    private enableExpanding;
    private disableExpanding;
    private calculateMaxHeight;
    private observeContentChanges;
    private disableContentFocus;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiOverflowComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiOverflowComponent, "sie-ui-overflow", never, { "limit": { "alias": "limit"; "required": false; }; "forBreakpoints": { "alias": "forBreakpoints"; "required": false; }; "headlineCollapsed": { "alias": "headlineCollapsed"; "required": false; }; "headlineExpanded": { "alias": "headlineExpanded"; "required": false; }; "useGradient": { "alias": "useGradient"; "required": false; }; "size": { "alias": "size"; "required": false; }; "buttonIndentationLeft": { "alias": "buttonIndentationLeft"; "required": false; }; "buttonIndentationTop": { "alias": "buttonIndentationTop"; "required": false; }; "centered": { "alias": "centered"; "required": false; }; "theme": { "alias": "theme"; "required": false; }; "useDynamicSubItemHeight": { "alias": "useDynamicSubItemHeight"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "showExpandButton": { "alias": "showExpandButton"; "required": false; }; "gradientColor": { "alias": "gradientColor"; "required": false; }; }, { "toggled": "toggled"; }, never, ["*"], false, never>;
}
//# sourceMappingURL=ui-overflow.component.d.ts.map