import { OnInit } from '@angular/core';
import { Subject } from 'rxjs';
import { SieIconRegistryService } from '@siemens/icons';
import { PaginationSize } from './ui-pagination.types';
import * as i0 from "@angular/core";
/**
 * # Pagination Component
 *
 * Pagination provides access mechanism to browse through subsets of search results or lists with many items.
 * Pagination is mainly used when there are pages which includes list and list items. For example, Search results page.
 *
 * ## Content
 *
 * The pagination component does not accept any content.
 *
 * ## Code example
 * @example ```html
 * <sie-ui-pagination
 *  [totalPages]=“7”
 *  [activePage]=“4”
 *  ariaLabel="Pagination"
 *  ariaLabelActivePage="Active Page"
 *  ariaLabelSwitchToNextPage="Next page"
 *  ariaLabelSwitchToPage="Switch to page"
 *  ariaLabelSwitchToPreviousPage="Previous page"
 *  (pageSelected)="onPageSelection($event)"
 * ></sie-ui-pagination>
 * ```
 */
export declare class UiPaginationComponent implements OnInit {
    iconReg: SieIconRegistryService;
    /**
     * Aria label for the pagination
     * @default ''
     */
    ariaLabel: string;
    /**
     * Aria label for the active page button
     * @default ''
     */
    ariaLabelActivePage: string;
    /**
     * Aria label for the non-active page button
     * @default ''
     */
    ariaLabelSwitchToPage: string;
    /**
     * Aria label for switch to next page button
     * @default ''
     */
    ariaLabelSwitchToNextPage: string;
    /**
     * Aria label for switch to previous page button
     * @default ''
     */
    ariaLabelSwitchToPreviousPage: string;
    /**
     * @param value Set the text of the tooltip when the last page reached
     */
    resultLimitReachedTooltipLabel: string;
    /**
     * @param value Set the total number of pages
     */
    set totalPages(value: number);
    get totalPages(): number;
    /**
     * Set the currently active page
     */
    set activePage(value: number);
    get activePage(): number;
    /**
     * Defined based on the {@link PaginationSize pagination size} whether 5 or 7 visible pages are displayed.
     * @default 'regular' 7 visible pages
     */
    paginationSize: PaginationSize;
    /**
     * Event triggered when the current active page is changed
     */
    pageSelected: Subject<number>;
    /** @ignore */
    pageNumbers: Array<{
        label: string;
        value: number;
        bigSpaceNeeded: boolean;
    }>;
    private _activePage;
    private _totalPages;
    private _visiblePages;
    private _maxButtonWithoutEllipsis;
    private _itemsBeforeOrAfterActivePage;
    private readonly PAGE_AND_ELLIPSIS;
    private readonly ELLIPSIS_JUMP_STEP;
    constructor(iconReg: SieIconRegistryService);
    ngOnInit(): void;
    /** @ignore */
    changePage(newPageNumber: number): void;
    private updatePaginationSettings;
    private arrangePagination;
    private paginationRendering;
    private addPageNumbers;
    private addPreviousEllipsis;
    private getEllipsisNextPage;
    /** @ignore */
    getPageSRText(active: boolean, page: number): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiPaginationComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiPaginationComponent, "sie-ui-pagination", never, { "ariaLabel": { "alias": "ariaLabel"; "required": false; }; "ariaLabelActivePage": { "alias": "ariaLabelActivePage"; "required": false; }; "ariaLabelSwitchToPage": { "alias": "ariaLabelSwitchToPage"; "required": false; }; "ariaLabelSwitchToNextPage": { "alias": "ariaLabelSwitchToNextPage"; "required": false; }; "ariaLabelSwitchToPreviousPage": { "alias": "ariaLabelSwitchToPreviousPage"; "required": false; }; "resultLimitReachedTooltipLabel": { "alias": "resultLimitReachedTooltipLabel"; "required": false; }; "totalPages": { "alias": "totalPages"; "required": false; }; "activePage": { "alias": "activePage"; "required": false; }; "paginationSize": { "alias": "paginationSize"; "required": false; }; }, { "pageSelected": "pageSelected"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-pagination.component.d.ts.map