import { OnChanges, SimpleChanges } from '@angular/core';
import { UiAccountIdHashingOption, UiAccountIdSize } from '../ui-account-identifier/ui-account-identifier.model';
import { UiPeopleListAccount, UiPeopleListSize } from './ui-people-list.model';
import * as i0 from "@angular/core";
/**
 * # People List Component
 *
 * People List is used as an optimized experience when interacting with the "People Bubbles".
 *
 * ## Component variations
 *
 * The People List component has no variations.
 *
 * ## Content
 *
 * The People List component does not accept any content.
 *
 * ## Code example
 * @example
 * Template:
 * ```html
 *  <sie-ui-people-list
 *    [accounts]="accountsData"
 *    [size]="'small'"
 *    [forHashing]="'name'"
 *    [count]="'2'"
 *    [countTooltip]="'Anna Adams\nPeter Fox'"
 *    [loading]="false"
 *   ></sie-ui-rich-snippet>
 * ```
 *  ```ts
 * const accountsData = [
 *  {
 *    initials: 'BZ',
 *    name: 'Benno Zerr',
 *    status: 'online'
 *  },
 *  {
 *    initials: 'HH',
 *    name: 'Herbie Hancock',
 *    status: 'neutral',
 *    avatarImage: 'https://sieportaldev.siemens.com/images-support-page/avatar_2.jpg',
 *  }
 * ];
 * ```
 */
export declare class UiPeopleListComponent implements OnChanges {
    /**
     * Defines the count number that will be displayed in "Overflow bubble".
     */
    set count(value: string);
    get count(): string;
    /**
     * List of {@link UiPeopleListAccount possible items (accounts)} to display.
     * @default []
     */
    set accounts(value: UiPeopleListAccount[]);
    get accountsDisplay(): UiPeopleListAccount[];
    /**
     * Defines the {@link UiPeopleListSize size} of People List component.
     * @default 'small'
     */
    size: UiPeopleListSize;
    /**
     * Defines the content that will be displayed in "Overflow bubble" popover.
     * Plain text with new line possible (\n)
     */
    countTooltip: string;
    /**
     * Defines if UiPeopleListSkeleton should be displayed.
     * @default false
     */
    loading: boolean;
    /**
     * @param value Defines which {@link UiAccountIdHashingOption attribute} should be used for color hashing to determine the background color of UiAccountIdentifierComponent.
     * @default 'name'
     */
    forHashing: UiAccountIdHashingOption;
    /** @ignore */
    accountIdSize: UiAccountIdSize;
    /** @ignore */
    skeletonSize: UiPeopleListSize;
    /** @ignore */
    displayOverflowBubble: boolean;
    private _count;
    private _allAccounts;
    /** @ignore */
    ngOnChanges(changes: SimpleChanges): void;
    private mapSizeToAccountIdSize;
    private updateDisplayedAccounts;
    private setOverflowBubbleDisplay;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiPeopleListComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiPeopleListComponent, "sie-ui-people-list", never, { "count": { "alias": "count"; "required": false; }; "accounts": { "alias": "accounts"; "required": false; }; "size": { "alias": "size"; "required": false; }; "countTooltip": { "alias": "countTooltip"; "required": false; }; "loading": { "alias": "loading"; "required": false; }; "forHashing": { "alias": "forHashing"; "required": false; }; }, {}, never, never, false, never>;
    static ngAcceptInputType_count: unknown;
    static ngAcceptInputType_loading: unknown;
}
//# sourceMappingURL=ui-people-list.component.d.ts.map