import { ElementRef, OnDestroy, OnInit, TemplateRef, ViewContainerRef } from '@angular/core';
import { Subject } from 'rxjs';
import { PopoverPlacement, PopoverSize } from './ui-popover.types';
import * as i0 from "@angular/core";
/**
 * This directive is used to display the popover
 */
export declare class UiPopoverDirective implements OnDestroy, OnInit {
    private readonly element;
    private readonly vcr;
    /**
     * Content that is displayed in richtext within the popover
     */
    set content(value: string);
    get content(): string;
    /**
     * Content of the template that is displayed in the popover
     */
    popoverTemplate?: TemplateRef<unknown>;
    /**
     * Defines {@link PopoverSize size} of the popover
     * @default 'l'
     */
    popoverSize: PopoverSize;
    /**
     * Defines {@link PopoverPlacement placement} of the popover
     * @default 'top'
     */
    popoverPlacement: PopoverPlacement;
    /**
     * Defines if popover has animation
     * @default false
     */
    popoverAnimation: boolean;
    /**
     * Defines if the animation of the popover is active
     */
    popoverPlayAnimation: Subject<boolean>;
    /**
     * Defines the timeout when the animation will hide the popover if it is active
     * @default 3000
     */
    popoverAnimationHideAfterTimeoutMS: number;
    /**
     * Defines if the theme of the popover is light
     * @default false
     */
    popoverLightTheme: boolean;
    private _content;
    private componentRef;
    private popoverTimeout;
    private hoveredSubscription;
    constructor(element: ElementRef, vcr: ViewContainerRef);
    openOnMouseEnter(): void;
    closeOnMouseLeave(): void;
    private popoverStateListener;
    private openPopover;
    private closePopover;
    private destroy;
    /** @ignore */
    ngOnInit(): void;
    /** @ignore */
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiPopoverDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<UiPopoverDirective, "[sieUiPopover]", never, { "content": { "alias": "content"; "required": false; }; "popoverTemplate": { "alias": "popoverTemplate"; "required": false; }; "popoverSize": { "alias": "popoverSize"; "required": false; }; "popoverPlacement": { "alias": "popoverPlacement"; "required": false; }; "popoverAnimation": { "alias": "popoverAnimation"; "required": false; }; "popoverPlayAnimation": { "alias": "popoverPlayAnimation"; "required": false; }; "popoverAnimationHideAfterTimeoutMS": { "alias": "popoverAnimationHideAfterTimeoutMS"; "required": false; }; "popoverLightTheme": { "alias": "popoverLightTheme"; "required": false; }; }, {}, never, never, false, never>;
}
//# sourceMappingURL=ui-popover.directive.d.ts.map