import { ChangeDetectorRef } from '@angular/core';
import { Subject } from 'rxjs';
import { ProgressStep } from './ui-progress-step/ui-progress-step.model';
import * as i0 from "@angular/core";
/**
 * # Progress Tracker component
 *
 * The Progress Tracker adds a mechanism to display various steps so that the user has an idea where they are located in
 * the process. This can be used for processes like checkout, workflows or feedback forms.
 *
 *
 * ## Component variations
 *
 * There are no variations as of now.
 * Currently, only the variant "Horizontal progress tracker" is implemented
 *
 * ## Content
 *
 * The progress tracker component does not accept any content.
 *
 *
 * ## Code example
 * @example ```html
 * <sie-ui-progress-tracker
 *   [steps]="[
 *     {
 *       state: 'completed',
 *       label: '1. Step'
 *     },
 *     {
 *       state: 'active',
 *       label: '2. Step'
 *     }
 *   ]"
 *   (progressStepSelected)="onStepSelected($event)"
 * ></sie-ui-progress-tracker>
 * ```
 */
export declare class UiProgressTrackerComponent {
    private readonly cdr;
    /**
     * It allows the progress tracker to be centered
     */
    variant: 'default' | 'centered';
    /**
     * @param steps Displayed {@link ProgressStep steps} and their states (limited to 7)
     */
    set steps(steps: ProgressStep[]);
    get steps(): ProgressStep[];
    /**
     * Event triggered when a step is selected by the user. The payload of the event is of type `number` and represents the
     * selected step.
     */
    progressStepSelected: Subject<number>;
    maxWidth: number;
    isWideLabel: boolean;
    private _steps;
    constructor(cdr: ChangeDetectorRef);
    updateView(): void;
    private calculatePosition;
    private checkIfProgressTrackerHasValue;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiProgressTrackerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiProgressTrackerComponent, "sie-ui-progress-tracker", never, { "variant": { "alias": "variant"; "required": false; }; "steps": { "alias": "steps"; "required": false; }; }, { "progressStepSelected": "progressStepSelected"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-progress-tracker.component.d.ts.map