import { EventEmitter, OnInit } from '@angular/core';
import { SieIconRegistryService } from '@siemens/icons';
import { AbstractControl, ValidationErrors } from '@angular/forms';
import { NgFormControlDirective } from '../ui-form-control/ui-ng-form-control.directive';
import { UiRadioButtonModel } from '../ui-radio-button/ui-radio-button.model';
import * as i0 from "@angular/core";
/**
 * # Radio Button Group Component
 *
 * Radio buttons support compulsory selection of one single option out of multiple, mutually exclusive options.
 *
 * ## Component variations
 * - Standard version (when `label` value (with or without `icons` value) is defined)
 * - Condensed version (when no `label` nor `icons` value is defined)
 * - Light theme
 * - Dark theme
 * - Disabled
 * - Readonly
 * - Invalid
 *
 * ## Content
 *
 * The radio button component does not accept any content.
 *
 * ## Code example
 * @example ```html
 * <sie-ui-radio-button-group
 *   [radioButtons]="[
 *     {
 *       label: 'Apple',
 *       id: 'a'
 *     },
 *     {
 *       label: 'Banana',
 *       id: 'b'
 *     }
 *   ]"
 *   label="Choose your daily fruit"
 *   [selectedId]="'a'"
 * ></sie-ui-radio-button-group>
 * ```
 */
export declare class UiRadioButtonGroupComponent extends NgFormControlDirective implements OnInit {
    iconReg: SieIconRegistryService;
    /**
     * @param value Flag can be used to overrule disabled flag on the items itself
     * @default false
     */
    set disabled(value: boolean);
    get disabled(): boolean;
    /**
     * Defines which button of the component is selected by default (controlled through id set in 'radioButtons' input)
     * @default ''
     */
    selectedId: any;
    /**
     * Used to define content in radio buttons group. Checkout {@link UiRadioButtonGroupModel}
     * @default empty array
     */
    radioButtons: UiRadioButtonModel[];
    /**
     * @param value Used to add focus state on the radio button selected through `selectedId` input. It will be possible
     * to add focus on the selected option until the selected option is changed
     * @default false
     */
    set focusRadioButton(value: boolean);
    get focusRadioButton(): boolean;
    /**
     * @param value adds styles for required state to the placeholder when set to true
     * @default false
     */
    set required(value: boolean);
    get required(): boolean;
    /**
     * Event when a different radio button is selected
     */
    selectedIdChange: EventEmitter<string>;
    private _focusRadioButton;
    private _required;
    constructor(iconReg: SieIconRegistryService);
    /** @ignore */
    ngOnInit(): void;
    /** @ignore */
    selected(id: string): void;
    /** @ignore */
    getSelectedItem(selectedId: string): UiRadioButtonModel;
    /** @ignore */
    validateInternal(control: AbstractControl): ValidationErrors | null;
    /** @ignore */
    writeValue(value: string): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiRadioButtonGroupComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiRadioButtonGroupComponent, "sie-ui-radio-button-group", never, { "disabled": { "alias": "disabled"; "required": false; }; "selectedId": { "alias": "selectedId"; "required": false; }; "radioButtons": { "alias": "radioButtons"; "required": false; }; "focusRadioButton": { "alias": "focusRadioButton"; "required": false; }; "required": { "alias": "required"; "required": false; }; }, { "selectedIdChange": "selectedIdChange"; }, never, ["[slot=radio-button-group-content]"], false, never>;
}
//# sourceMappingURL=ui-radio-button-group.component.d.ts.map