import { EventEmitter, OnInit, ElementRef } from '@angular/core';
import { SieIconRegistryService } from '@siemens/icons';
import { AbstractControl, ValidationErrors } from '@angular/forms';
import { NgFormControlDirective } from '../ui-form-control/ui-ng-form-control.directive';
import { UiRadioButtonModel } from './ui-radio-button.model';
import * as i0 from "@angular/core";
/**
 * # Radio Button Component
 *
 * Radio button support one single Radio Button Input.
 *
 * ## Component variations
 * - Standard version (when `label` value (with or without `icons` value) is defined)
 * - Condensed version (when no `label` nor `icons` value is defined)
 * - Light theme
 * - Dark theme
 * - Disabled
 * - Readonly
 * - Invalid
 *
 * ## Content
 *
 * The radio button component does not accept any content.
 *
 * ## Code example
 * @example ```html
 * <sie-ui-radio-button
 *   [radioButton]="{
 *       label: 'Apple',
 *       id: 'a'
 *     }
 *   "
 *   label="Choose your daily fruit"
 *   [checked]="true"
 *   [disabled]="true"
 * ></sie-ui-radio-button>
 * ```
 */
export declare class UiRadioButtonComponent extends NgFormControlDirective implements OnInit {
    iconReg: SieIconRegistryService;
    /** @ignore */
    set radioButtonInput(radioButtonInput: ElementRef);
    /**
     * @param value Flag can be used to overrule disabled flag on the items itself
     * @default false
     */
    set disabled(value: boolean);
    get disabled(): boolean;
    /**
     * Defines the checked state of the component
     * @default false
     */
    set checked(value: boolean);
    get checked(): boolean;
    /**
     * Used to define content in radio button. Checkout {@link UiRadioButtonModel}
     * @default empty array
     */
    radioButton: UiRadioButtonModel;
    /**
     * @param value Used to add focus state on the radio button selected through `selectedId` input. It will be possible
     * to add focus on the selected option until the selected option is changed
     * @default false
     */
    set focusRadioButton(value: boolean);
    get focusRadioButton(): boolean;
    /**
     * @param value adds styles for required state to the placeholder when set to true
     * @default false
     */
    set required(value: boolean);
    get required(): boolean;
    /**
     * Event when a different radio button is selected
     */
    selected: EventEmitter<string>;
    _disabled: boolean;
    _focusRadioButton: boolean;
    private _required;
    private _checked;
    constructor(iconReg: SieIconRegistryService);
    /** @ignore */
    ngOnInit(): void;
    /** @ignore */
    onSelect(id: string): void;
    /** @ignore */
    validateInternal(control: AbstractControl): ValidationErrors | null;
    /** @ignore */
    writeValue(value: boolean): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiRadioButtonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiRadioButtonComponent, "sie-ui-radio-button", never, { "disabled": { "alias": "disabled"; "required": false; }; "checked": { "alias": "checked"; "required": false; }; "radioButton": { "alias": "radioButton"; "required": false; }; "focusRadioButton": { "alias": "focusRadioButton"; "required": false; }; "required": { "alias": "required"; "required": false; }; }, { "selected": "selected"; }, never, ["[slot=radio-button-content]"], false, never>;
}
//# sourceMappingURL=ui-radio-button.component.d.ts.map