import { SieIcon, SieIconRegistryService } from '@siemens/icons';
import { LocaleString } from '@siemens/core';
import * as i0 from "@angular/core";
/**
 * # Rating Stars component
 *
 * Rating stars are used to show rating for support materials such as downloads, FAQs, manuals etc.
 *
 * ## Component variations
 *
 * - Rated
 * - Not rated
 *
 * ## Content
 *
 * The rating stars component does not accept any content.
 *
 * ## Code example
 * @example ```html
 * <sie-ui-rating-stars
 *   [rating]="5"
 *   [ratingCount]="1000"
 *   [tooltip]="'Average based on 1000 customer ratings.'"
 *   [locale]="'en'"
 * ></sie-ui-rating-stars>
 * ```
 */
export declare class UiRatingStarsComponent {
    /**
     * Sets the tooltip message
     */
    tooltip: string;
    private _ratingCount;
    /**
     * @param value Sets the number of ratings
     */
    set ratingCount(value: number);
    get ratingCount(): number;
    /**
     * @param rating Rating value that is displayed within the component
     * @default `0`
     */
    set rating(rating: number);
    /**
     * Locale being used for formatting purposes
     */
    locale: LocaleString;
    /** @ignore */
    icons: SieIcon[];
    constructor(iconReg: SieIconRegistryService);
    private static determineIcon;
    private static determineIcons;
    /** @ignore */
    classForIcon(icon: SieIcon): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiRatingStarsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiRatingStarsComponent, "sie-ui-rating-stars", never, { "tooltip": { "alias": "tooltip"; "required": false; }; "ratingCount": { "alias": "ratingCount"; "required": false; }; "rating": { "alias": "rating"; "required": false; }; "locale": { "alias": "locale"; "required": false; }; }, {}, never, never, false, never>;
}
//# sourceMappingURL=ui-rating-stars.component.d.ts.map