import { EventEmitter, OnDestroy, ViewContainerRef } from '@angular/core';
import { UiRichSnippetModel, UiRichSnippetSkeletonSize, UiRichSnippetSecondaryMetaPosition, UiRichSnippetType, UiRichSnippetVariant } from './ui-rich-snippet.model';
import { SieIconRegistryService } from '@siemens/icons';
import { UiAutoDestroyableComponent } from '../shared/components/ui-auto-destroyable.component';
import * as i0 from "@angular/core";
/**
 * # Rich Snippet Component
 * Rich snippet is used as a preview and a trigger to the detailed information.
 *
 * ## Component types
 *
 * - Content
 * - Link
 *
 * ## Component variations
 *
 * - Standard
 * - No border
 *
 * ## Content
 *
 * The Rich Snippet component does not accept any content.
 *
 * ## Code example
 * @example
 * Template:
 * ```html
 *  <sie-ui-rich-snippet [item]="richSnippetData" [type]="'link'" [closeable]="true" [secondaryMetaPosition]="'top'" [showThumbnail]="false"></sie-ui-rich-snippet>
 * ```
 *  ```ts
 * const richSnippetData: = {
 *   title: 'Lorem ipsum dolor sit amet',
 *   primaryMeta: '<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit</p>',
 *   secondaryMeta: 'Something',
 *   secondaryMetaIcon: SieIcon.Support,
 *   url: 'https://sieportaldev.siemens.com/en-ww/home',
 *   target: '_blank'
 * };
 * ```
 */
export declare class UiRichSnippetComponent extends UiAutoDestroyableComponent implements OnDestroy {
    readonly iconReg: SieIconRegistryService;
    protected readonly vcr: ViewContainerRef;
    /**
     * The main source of {@link UiRichSnippetModel component data}
     */
    set item(value: UiRichSnippetModel);
    get item(): UiRichSnippetModel;
    /**
     * Defines whether the component can be closed
     * @default false
     */
    set closeable(value: boolean);
    get closeable(): boolean;
    /**
     * Defines if the thumbnail should be shown
     * @default true
     */
    set showThumbnail(value: boolean);
    get showThumbnail(): boolean;
    /**
     * Defines the component {@link UiRichSnippetVariant variance}
     * @default 'standard'
     */
    set variant(value: UiRichSnippetVariant);
    get variant(): UiRichSnippetVariant;
    /**
     * Defines the component {@link UiRichSnippetType type}
     * @default 'content'
     */
    type: UiRichSnippetType;
    /**
     * {@link UiRichSnippetSecondaryMetaPosition Position} of the secondary metadata
     * @default 'bottom'
     */
    secondaryMetaPosition: UiRichSnippetSecondaryMetaPosition;
    /**
     * Screen reader label for close icon when component is closeable
     * @default ''
     */
    screenReaderCloseIcon: string;
    /**
     * Defines {@link UiRichSnippetSkeletonSize size} of the skeleton
     * @default 'normal'
     */
    skeletonSize: UiRichSnippetSkeletonSize;
    /**
     * Event triggered when the component is closed
     */
    closed: EventEmitter<Event>;
    /** @ignore */
    imgFailedToLoad: boolean;
    /** @ignore */
    primaryMetaTruncationLines: number;
    private _closeable;
    private _showThumbnail;
    private _item;
    private _variant;
    constructor(iconReg: SieIconRegistryService, vcr: ViewContainerRef);
    /** @ignore */
    ngOnDestroy(): void;
    /** @ignore */
    loadPlaceholder(imageLoaded: boolean): void;
    /** @ignore */
    navigateLink(href: string, target?: string): void;
    /** @ignore */
    destroy(event: Event): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiRichSnippetComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiRichSnippetComponent, "sie-ui-rich-snippet", never, { "item": { "alias": "item"; "required": false; }; "closeable": { "alias": "closeable"; "required": false; }; "showThumbnail": { "alias": "showThumbnail"; "required": false; }; "variant": { "alias": "variant"; "required": false; }; "type": { "alias": "type"; "required": false; }; "secondaryMetaPosition": { "alias": "secondaryMetaPosition"; "required": false; }; "screenReaderCloseIcon": { "alias": "screenReaderCloseIcon"; "required": false; }; "skeletonSize": { "alias": "skeletonSize"; "required": false; }; }, { "closed": "closed"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-rich-snippet.component.d.ts.map