import { AfterViewInit, ChangeDetectorRef, ComponentRef, ElementRef, Renderer2, ViewContainerRef } from '@angular/core';
import { ThemeVariant } from '@siemens/core';
import { UiUnderlineTooltipComponent } from '../ui-underline-tooltip/ui-underline-tooltip.component';
import * as i0 from "@angular/core";
/**
 * # Richtext Component
 * Rich text instantiates typographic styles. It is always used when text containing
 * multiple lines and formats is shown on the page. Rich text can have regular or bold style.
 * They can be used within any defined copy styles but not with the headlines.
 *
 * ## Component variations
 *
 * - Light theme text
 * - Dark theme text
 *
 * ## Content
 *
 * The Richtext component does not accept any content.
 *
 * ## Code example
 * @example
 * Template:
 * ```html
 * <sie-ui-richtext [content]="content" [theme]="'dark'"></sie-ui-richtext>
 * ```
 */
export declare class UiRichtextComponent implements AfterViewInit {
    renderer: Renderer2;
    private readonly document;
    private readonly el;
    private readonly vcRef;
    private readonly cdr;
    /**
     * Defines content of the Richtext component.
     */
    set content(value: string);
    get content(): string;
    /**
     * Defines {@link ThemeVariant Variant} theme of the Richtext component.
     * @default 'light'
     */
    theme: ThemeVariant;
    /**
     * Defines white listed html tags shown in the richtext container
     */
    whiteListedTags: Set<string>;
    private _content;
    constructor(renderer: Renderer2, document: Document, el: ElementRef, vcRef: ViewContainerRef, cdr: ChangeDetectorRef);
    /** @ignore */
    ngAfterViewInit(): void;
    /** @ignore */
    createLink(innerText: string, linkSource: string, target: string): HTMLAnchorElement;
    createUnderlineWithTooltip(text: string, tooltipText: string): ComponentRef<UiUnderlineTooltipComponent>;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiRichtextComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiRichtextComponent, "sie-ui-richtext", never, { "content": { "alias": "content"; "required": false; }; "theme": { "alias": "theme"; "required": false; }; "whiteListedTags": { "alias": "whiteListedTags"; "required": false; }; }, {}, never, ["*"], false, never>;
}
//# sourceMappingURL=ui-richtext.component.d.ts.map