import { OnInit } from '@angular/core';
import { ThemeVariant } from '@siemens/core';
import { UiSpinnerSize } from '../ui-spinner.types';
import * as i0 from "@angular/core";
/**
 * # Progress Spinner Component
 *
 * Progress spinner is used to indicate the processing of a user action.
 *
 * ## Component variations
 *
 * - Light/dark theme
 *
 * ## Content
 *
 * The spinner component does not accept any content.
 *
 * ## Code example
 *
 * @example ```html
 * <sie-ui-progress-spinner
 *  [percentage]="50"
 *  [message]="'Loading...'"
 *  [size]="'m'"
 * ></sie-ui-progress-spinner>
 * ```
 */
export declare class UiProgressSpinnerComponent implements OnInit {
    /**
     * Defines {@link ThemeVariant Variant} theme of the progress spinner.
     * @default 'light'
     */
    theme: ThemeVariant;
    /**
     * Defines message displayed below progress spinner
     */
    message: string;
    /**
     * Defines {@link UiSpinnerSize size} of progress spinner
     * @default 's'
     */
    set size(value: UiSpinnerSize);
    get size(): UiSpinnerSize;
    /**
     * Defines the percentage indicated in the progress spinner
     */
    set percentage(value: number);
    /** @ignore */
    get percentage(): number;
    /**
     * @param overlayOnTop Indication whether a progress spinner's overlay should be covering the whole page (default) or just the container
     * @default true
     */
    set overlayOnTop(value: boolean);
    get overlayOnTop(): boolean;
    /**
     * @param overlay indication whether a progress spinner is positioned inside an overlay
     * @default false
     */
    set overlay(overlay: boolean);
    get overlay(): boolean;
    /** @ignore */
    get circumference(): string;
    /** @ignore */
    indicatorDashArray: number;
    /** @ignore */
    indicatorDashOffset: number;
    private _size;
    private _overlayOnTop;
    private _overlay;
    private _percentage;
    private _circumference;
    private _strokeSize;
    private _svgSize;
    private calculateIndicatorPercentage;
    private setSvgDefinitions;
    /** @ignore */
    ngOnInit(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiProgressSpinnerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiProgressSpinnerComponent, "sie-ui-progress-spinner", never, { "theme": { "alias": "theme"; "required": false; }; "message": { "alias": "message"; "required": false; }; "size": { "alias": "size"; "required": false; }; "percentage": { "alias": "percentage"; "required": false; }; "overlayOnTop": { "alias": "overlayOnTop"; "required": false; }; "overlay": { "alias": "overlay"; "required": false; }; }, {}, never, never, false, never>;
}
//# sourceMappingURL=ui-progress-spinner.component.d.ts.map