import { UiSpinnerSize } from './ui-spinner.types';
import { Subject } from 'rxjs';
import * as i0 from "@angular/core";
/**
 * # Spinner Component
 *
 * Spinner is used to indicate the processing of a user action.
 *
 * ## Component variations
 *
 * There are no variations
 *
 * ## Content
 *
 * The spinner component does not accept any content.
 *
 * ## Code example
 *
 * @example ```html
 * <sie-ui-spinner
 *  [active]="true"
 *  [message]="'Loading...'"
 *  [size]="'m'"
 *  (animationEnded)="closeSpinner()"
 * ></sie-ui-spinner>
 * ```
 */
export declare class UiSpinnerComponent {
    /**
     * Defines {@link UiSpinnerSize size} of spinner
     * @default 's'
     */
    size: UiSpinnerSize;
    /**
     * Defines message displayed below spinner
     */
    message?: string;
    /**
     * @param overlayOnTop Indication whether a spinner's overlay should be covering the whole page (default) or just the container
     * @default true
     */
    set overlayOnTop(value: boolean);
    get overlayOnTop(): boolean;
    /**
     * @param overlay indication whether a spinner is positioned inside an overlay
     * @default false
     */
    set overlay(overlay: boolean);
    get overlay(): boolean;
    /**
     * @param active whether a spinner should be visible or not
     * @default false
     */
    set active(active: boolean);
    get active(): boolean;
    /**
     * Triggered when the animation of the spinner ended
     */
    animationEnded: Subject<void>;
    /**
     * Defines whether the animation is still running or not
     */
    get animationIsRunning(): boolean;
    private _overlayOnTop;
    private _overlay;
    private _active;
    private _animationIsRunning;
    /** @ignore */
    onAnimationEnd(event: AnimationEvent): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiSpinnerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiSpinnerComponent, "sie-ui-spinner", never, { "size": { "alias": "size"; "required": false; }; "message": { "alias": "message"; "required": false; }; "overlayOnTop": { "alias": "overlayOnTop"; "required": false; }; "overlay": { "alias": "overlay"; "required": false; }; "active": { "alias": "active"; "required": false; }; }, { "animationEnded": "animationEnded"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-spinner.component.d.ts.map