import { EventEmitter, OnInit } from '@angular/core';
import { AbstractControl, ValidationErrors } from '@angular/forms';
import { NgFormControlDirective } from '../ui-form-control/ui-ng-form-control.directive';
import { UiSwitchButtonGroupModel } from './ui-switch-button-group.model';
import * as i0 from "@angular/core";
/**
 * # Switch Button Group component
 *
 * A switch button group allows the user to select one of many logically grouped items,
 * comparable to a radio button group.
 *
 * ## Component variations
 *
 * There are no variations.
 *
 * ## Content
 *
 * The Switch Button Group component does not accept any content.
 *
 * ## Code example
 * @example ```html
 *  <sie-ui-switch-button-group
 *    [data]="switchButtonGroupData"
 *    selectedId="sb-l-2"
 *    name="group 1"
 *  ></sie-ui-switch-button-group>
 * ```
 *
 * Example of switch button group data:
 * ```ts
 * switchButtonGroupData = [
 *  {
 *    id: 'sb-l-1',
 *    label: 'One'
 *  },
 *  {
 *    id: 'sb-l-2',
 *    label: 'TWo',
 *    disabled: true
 *  }
 *];
 * ```
 */
export declare class UiSwitchButtonGroupComponent extends NgFormControlDirective implements OnInit {
    /**
     * @param value Defines source {@link UiSwitchButtonGroupModel data} of the component
     */
    set data(value: UiSwitchButtonGroupModel[]);
    get data(): UiSwitchButtonGroupModel[];
    /**
     * Defines the id of the currently selected button. If not defined, the first button will be selected by default.
     * @default '' (empty string)
     */
    selectedId: string;
    /**
     * Event triggered when another button that is not selected is clicked.
     * The event data is id of the selected button.
     */
    selectedIdChange: EventEmitter<string>;
    private _data;
    /** @ignore */
    ngOnInit(): void;
    /** @ignore */
    selected(id: string): void;
    /** @ignore */
    validateInternal(control: AbstractControl): ValidationErrors | null;
    /** @ignore */
    writeValue(value: string): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiSwitchButtonGroupComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiSwitchButtonGroupComponent, "sie-ui-switch-button-group", never, { "data": { "alias": "data"; "required": false; }; "selectedId": { "alias": "selectedId"; "required": false; }; }, { "selectedIdChange": "selectedIdChange"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-switch-button-group.component.d.ts.map