/**
 * Defines the basic properties of the table
 */
export interface UiTableModel {
    /**
     * Width of the entire table
     */
    width?: string;
    /**
     * Height of the entire table
     */
    height?: string;
    /**
     * Table header data
     */
    tHead?: UiTableSectionModel;
    /**
     * Table body data
     */
    tBodies: UiTableSectionModel[];
    /**
     * Table footer data
     */
    tFoot?: UiTableSectionModel;
    /**
     * Table caption
     */
    caption?: string;
}
/**
 * Defines table section content
 */
export interface UiTableSectionModel {
    rows: Array<UiTableRowModel>;
}
/**
 * Defines row content
 */
export interface UiTableRowModel {
    cells?: Array<UiTableCellModel>;
}
/**
 * Type for cell alignment
 */
export type UiCellAlignment = 'left' | 'right' | 'center';
/**
 * Defines table cell
 */
export interface UiTableCellModel {
    /**
     * Span of the column
     */
    colspan?: number;
    /**
     * Span of the row
     */
    rowspan?: number;
    /**
     * Defines if cell should use truncation
     */
    truncate?: boolean;
    /**
     * Defines if the sequence of whitespace should collapse into single whitespace
     */
    noWrap?: boolean;
    /**
     * Content of the cell
     */
    value: string;
    /**
     * Alignments of the cell content
     */
    alignment?: UiCellAlignment;
    /**
     * Width of the cell
     */
    width?: string;
    /**
     * Height of the cell
     */
    height?: string;
}
//# sourceMappingURL=ui-table.model.d.ts.map