import { PlainObject, ThemeVariant } from '@siemens/core';
import { BadgeStatus, BadgeType } from '../../ui-badge/ui-badge.types';
import { SieIcon } from '@siemens/icons';
/**
 * Tabs controls variant:
 * - `contained`
 * - `un-contained`
 */
export type TabsControlsType = 'contained' | 'un-contained' | 'prominent-uncontained';
/**
 * Tabs controls headline alignment:
 * - `left`
 * - `center`
 * - `right`
 */
export type TabsControlsAlignment = 'left' | 'center' | 'right';
export interface TabsControlBadge {
    /**
     * Defines {@link BadgeType Type} type of the Badge component.
     */
    type: BadgeType;
    /**
     * Defines {@link ThemeVariant Variant} theme of the Badge component.
     */
    mode: ThemeVariant;
    /**
     * Defines {@link BadgeStatus Status} status of the Badge component.
     */
    status?: BadgeStatus;
    /**
     * Defines a number displayed in the Badge component.
     */
    number?: number;
}
export interface TabsControlIcon {
    /**
     * Defines {@link SieIcon Icon} icon of the Tab.
     */
    name: SieIcon;
    /**
     * Defines a color for the icon.
     */
    color?: string;
    /** @ignore */
    reactiveToState?: boolean;
}
export interface TabsControlConfig {
    /**
     * Defines value of tab title.
     */
    title: string;
    /**
     * Defines whether a tab is in disabled state or not.
     */
    disabled?: boolean;
    /**
     * Defines whether a tab should be hidden or not.
     */
    hide?: boolean;
    /**
     * Defines a number displayed next to a tab title.
     * (please use {@link TabsControlBadge Badge} number or count exclusively as
     * having both set would face an invalid use case).
     */
    count?: number;
    /**
     * Adds additional attributes to the tab (e.g.: for tracking)
     */
    dataAttributes?: PlainObject;
    /**
     * Defines {@link TabsControlBadge Badge} data for badge displayed in the tab.
     */
    badge?: TabsControlBadge;
    /**
     * Defines {@link TabsControlIcon Icon} the icon for the tab title.
     */
    icon?: TabsControlIcon;
}
//# sourceMappingURL=ui-tabs-controls.types.d.ts.map