import { ChangeDetectorRef, ElementRef, EventEmitter } from '@angular/core';
import { LayoutService } from '@siemens/core';
import { UiBaseTeaserDirective } from '../ui-base-teaser.directive';
import { UiMenuButtonModel } from '../../ui-menu-button/ui-menu-button.model';
import { UiTeaserModel } from '../ui-teaser.model';
import { UiChildActionEventModel } from '../../shared/models/child-action-event.model';
import * as i0 from "@angular/core";
/**
 * # Ad Teaser Component
 *
 * Ad Teasers provide a way to highlight a product, service or any other type of content that deserves users' attention.
 *
 * ## Component variations
 *
 * There are no variations.
 *
 * ## Content
 *
 * The Ad Teaser component does not accept any content.
 *
 * ## Code example
 * @example
 * Template:
 * ```html
 * <sie-ui-ad-teaser [buttonFullWidthOnViewportS]="false" [buttonAlignment]="'left'" [teaserData]="adTeaserData"></sie-ui-ad-teaser>
 * ```
 * Card Portrait item example:
 * ``` js
 * const adTeaserData = {
 *  id: 2,
 *  picture: {
 *    urlSmall:
 *     'https://assets.new.siemens.com/siemens/assets/api/uuid:c67c52de-8441-4e05-93ed-2644bed4f080/width:640/quality:LOW/AdobeStock-263584338.jpeg',
 *    urlMedium:
 *     'https://assets.new.siemens.com/siemens/assets/api/uuid:c67c52de-8441-4e05-93ed-2644bed4f080/width:1280/quality:MEDIUM/AdobeStock-263584338.jpeg',
 *    urlLarge:
 *     'https://assets.new.siemens.com/siemens/assets/api/uuid:c67c52de-8441-4e05-93ed-2644bed4f080/width:1920/quality:HIGH/AdobeStock-263584338.jpeg',
 *    altText: 'In case the image does not load..',
 *    mode: 'cover'
 *  },
 *  buttons: [
 *   {
 *     label: 'Register',
 *     link: 'https://new.siemens.com/global/en/company/fairs-events/digital-enterprise-virtual-summit.html#Registration',
 *     variant: 'secondary',
 *     background: 'dark',
 *     icon: 'UserAccount',
 *     iconPosition: 'leading',
 *     buttonType: 'link',
 *     target: '_self'
 *   }
 *  ],
 *  subTitle: 'Industry Mall and Industry Online Support are starting to evolve into one unified platform!',
 *  title: 'PROMO AD SiePortal: The integrated platform for your information, buying and order workflow.',
 *  linkLabel: 'Learn more',
 *  linkTarget: 'https://new.siemens.com/global/en/company/fairs-events/digital-enterprise-virtual-summit.html',
 *  linkType: 'link'
 *  };
 *```
 */
export declare class UiAdTeaserComponent extends UiBaseTeaserDirective {
    layoutService: LayoutService;
    cdr: ChangeDetectorRef;
    private readonly elementRef;
    private readonly document;
    /** @ignore */
    badge: ElementRef;
    /**
     * Depending on this number, certain styling will be applied to the ad teaser.
     */
    teaserCount: number;
    /**
     * Defines height of the ad teaser.
     */
    height: number;
    /**
     * {@link UiChildActionEventModel Event} triggered when the action in the dropdown is clicked or selected via keyboard
     * (options button on the ad teaser).
     */
    childActionClicked: EventEmitter<UiChildActionEventModel>;
    /** @ignore */
    ColorBackgroundTeaserOverlay: string;
    /** @ignore */
    personImage: string;
    /** @ignore */
    adTeaserBg: string;
    constructor(layoutService: LayoutService, cdr: ChangeDetectorRef, elementRef: ElementRef<HTMLElement>, document: Document);
    /** @ignore */
    ngOnInit(): void;
    /** @ignore */
    dropdownOptionSelected(button: UiMenuButtonModel, item: UiTeaserModel): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiAdTeaserComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiAdTeaserComponent, "sie-ui-ad-teaser", never, { "teaserCount": { "alias": "teaserCount"; "required": false; }; "height": { "alias": "height"; "required": false; }; }, { "childActionClicked": "childActionClicked"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-ad-teaser.component.d.ts.map