import { ChangeDetectorRef, EventEmitter, OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { Subject } from 'rxjs';
import { BreakpointKey, LayoutService } from '@siemens/core';
import { UiTeaserModel } from './ui-teaser.model';
import { UiButtonClickModel } from '../ui-button/base/ui-button.model';
import * as i0 from "@angular/core";
export declare class UiBaseTeaserDirective implements OnInit, OnDestroy, OnChanges {
    layoutService: LayoutService;
    cdr: ChangeDetectorRef;
    /**
     * The main source of the {@link UiTeaserModel teaser data} that should be displayed.
     */
    teaserData: UiTeaserModel;
    /**
     * Alignment of the buttons (when nothing is specified then the buttons are automatically left aligned).
     */
    buttonAlignment: 'left' | 'center' | 'right';
    /**
     * Special case for the carousel, it renders every teaser 3 times -> video modal should not be created 3 times.
     * @default false
     */
    ignoreVideoModal: boolean;
    /**
     * Defines if container-queries or media-queries are used for the teaser styling -> needed for carousel if containerStyling is enabled
     * NOTE: currently should only be used in combination with carousel
     * @default false
     */
    containerStyled: boolean;
    /**
     * When container-styled used provides container viewport to child
     * @default ''
     */
    set viewportContainer(key: BreakpointKey);
    get viewportContainer(): BreakpointKey;
    /**
     * Define should the button use the full width when the viewport is S (small).
     * @default false
     */
    buttonFullWidthOnViewportS: boolean;
    /**
     * {@link UiButtonClickModel Event} triggered when the button is clicked.
     */
    buttonClick: Subject<UiButtonClickModel>;
    /**
     * {@link UiTeaserModel Event} triggered when button is clicked and emit teaser data
     */
    cardClicked: EventEmitter<UiTeaserModel>;
    /** @ignore */
    imageUrl: string;
    /** @ignore */
    breakpointSActive: boolean;
    /** @ignore */
    smallViewport: boolean;
    /** @ignore */
    mediumViewport: boolean;
    private _breakpointKey;
    private readonly subscription;
    constructor(layoutService: LayoutService, cdr: ChangeDetectorRef);
    /** @ignore */
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    /** @ignore */
    ngOnDestroy(): void;
    private checkBreakpoint;
    private updateObservables;
    private updateViewportVars;
    /** @ignore */
    onButtonClick(event: UiButtonClickModel): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiBaseTeaserDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<UiBaseTeaserDirective, never, never, { "teaserData": { "alias": "teaserData"; "required": false; }; "buttonAlignment": { "alias": "buttonAlignment"; "required": false; }; "ignoreVideoModal": { "alias": "ignoreVideoModal"; "required": false; }; "containerStyled": { "alias": "containerStyled"; "required": false; }; "viewportContainer": { "alias": "viewportContainer"; "required": false; }; "buttonFullWidthOnViewportS": { "alias": "buttonFullWidthOnViewportS"; "required": false; }; }, { "buttonClick": "buttonClick"; "cardClicked": "cardClicked"; }, never, never, false, never>;
    static ngAcceptInputType_ignoreVideoModal: unknown;
    static ngAcceptInputType_containerStyled: unknown;
    static ngAcceptInputType_buttonFullWidthOnViewportS: unknown;
}
//# sourceMappingURL=ui-base-teaser.directive.d.ts.map