import { EventEmitter, OnDestroy, ViewContainerRef } from '@angular/core';
import { UiSpinnerSize } from '../ui-spinner';
import { SieIcon, SieIconRegistryService } from '@siemens/icons';
import { UiThumbnailStatus, UiThumbnailType } from './ui-thumbnail.model';
import { UiAutoDestroyableComponent } from '../shared/components/ui-auto-destroyable.component';
import * as i0 from "@angular/core";
/**
 * # Thumbnail Component
 *
 * The Thumbnail component provides a preview of an uploaded material.
 *
 * ## Component variations
 *
 * The Thumbnail component doesn't have any variations.
 *
 * ## Content
 *
 * The Thumbnail component does not accept any content.
 *
 * ## Code example
 * @example
 * Template:
 * ```html
 * <sie-ui-thumbnail [title]="Thumbnail title" [status]="success" [type]="file"></sie-ui-thumbnail>
 * ```
 */
export declare class UiThumbnailComponent extends UiAutoDestroyableComponent implements OnDestroy {
    readonly iconReg: SieIconRegistryService;
    protected vcr: ViewContainerRef;
    /**
     * @param icon {@link SieIcon Icon} Defines custom icon of the Thumbnail component.
     */
    set icon(icon: SieIcon);
    get icon(): SieIcon;
    /**
     * Defines title of the Thumbnail component.
     * @default ''
     */
    title: string;
    /**
     * Defines {@link UiThumbnailStatus Status} in which status the Thumbnail component will be shown.
     * @default 'success'
     */
    status: UiThumbnailStatus;
    /**
     * Defines {@link UiThumbnailType Type} in which type the Thumbnail component will be shown.
     * @default 'file'
     */
    type: UiThumbnailType;
    /**
     * Defines error message of the Thumbnail component if the component is in 'error' status
     * (see {@link UiThumbnailStatus Status})
     */
    errorMessage?: string;
    /**
     * Event triggered when the refresh button is clicked.
     */
    refreshActionClicked: EventEmitter<void>;
    /**
     * Event triggered when the close button is clicked.
     */
    closeActionClicked: EventEmitter<Event>;
    /** @ignore */
    spinnerSize: UiSpinnerSize;
    private _icon;
    constructor(iconReg: SieIconRegistryService, vcr: ViewContainerRef);
    /** @ignore */
    ngOnDestroy(): void;
    /** @ignore */
    onRefreshActionClicked(): void;
    /** @ignore */
    destroy(event: Event): void;
    /** @ignore */
    getIcon(): SieIcon;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiThumbnailComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiThumbnailComponent, "sie-ui-thumbnail", never, { "icon": { "alias": "icon"; "required": false; }; "title": { "alias": "title"; "required": false; }; "status": { "alias": "status"; "required": false; }; "type": { "alias": "type"; "required": false; }; "errorMessage": { "alias": "errorMessage"; "required": false; }; }, { "refreshActionClicked": "refreshActionClicked"; "closeActionClicked": "closeActionClicked"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-thumbnail.component.d.ts.map