import { ComponentBreakpointDefinition } from '@siemens/core';
import { SieIconRegistryService } from '@siemens/icons';
import { UiTileButtonGroupModel } from './ui-tile-button-group.model';
import * as i0 from "@angular/core";
/**
 * # Tile button group component
 *
 * Tile button group is a component that acts as a list of highlighted actions or links that allow user to perform actions or to jump from one context to the other.
 *
 * ## Component variations
 *
 * There are no variations.
 *
 * ## Content
 *
 * Tile button group does not accept any content.
 *
 * ## Code example
 * @example
 * Template:
 * ```html
 * <sie-ui-tile-button-group [tileButtonGroupData]="data"></sie-ui-tile-button-group-data>
 * ```
 *
 * Data example:
 * ``` js
 * const data = [
 *  {
 *    title: 'Tile button with two lines of text',
 *    icon: 'Newton_productCatalogue',
 *    link: {
 *      type: 'url',
 *      href: 'https://www.siemens.com',
 *      target: '_blank'
 *    }
 *  },
 *  {
 *    title: 'Services',
 *    icon: 'Service',
 *    link: {
 *      type: 'url',
 *      href: 'https://www.siemens.com',
 *      target: '_self'
 *    }
 *  },
 *  {
 *    title: 'Support requests',
 *    icon: 'Support',
 *    link: {
 *      type: 'url',
 *      href: 'https://www.siemens.com'
 *    }
 *  }
 * ];
 * ```
 */
export declare class UiTileButtonGroupComponent {
    readonly iconReg: SieIconRegistryService;
    /** @ignore */
    readonly tileButtonGroupViewports: ComponentBreakpointDefinition;
    /**
     * The main source of {@link UiTileButtonGroupModel Tile button group data}.
     */
    set tileButtonGroupData(value: UiTileButtonGroupModel[]);
    get tileButtonGroupData(): UiTileButtonGroupModel[];
    /** @ignore */
    minNumberOfTiles: number;
    /** @ignore */
    maxNumberOfTiles: number;
    private _tileButtonGroupData;
    constructor(iconReg: SieIconRegistryService);
    private loadIcons;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiTileButtonGroupComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiTileButtonGroupComponent, "sie-ui-tile-button-group", never, { "tileButtonGroupData": { "alias": "tileButtonGroupData"; "required": false; }; }, {}, never, never, false, never>;
}
//# sourceMappingURL=ui-tile-button-group.component.d.ts.map