import { UiBasicNavigationTarget } from '../shared/models';
import { UiToastType } from './ui-toast.types';
/**
 * Types of the toast message action
 */
export type ToastMessageActionType = 'RELOAD_CHILDREN' | 'RELOAD_ATTRIBUTES' | 'RELOAD_ATTACHMENT';
/**
 * Action item of the toast
 */
export declare type ToastMessageActionItem = {
    /**
     * ID of the toast
     */
    toastId: string;
    /**
     * {@link ToastMessageAdditionalData Additional data} of the toast
     */
    additionalData?: ToastMessageAdditionalData;
};
export declare type ToastMessageAdditionalData = {
    action: ToastMessageActionType;
    item?: any;
};
export interface UiToastModel {
    /**
     * Headline of the toast
     */
    headline: string;
    /**
     * Toast identifier, must be unique for each toast
     */
    id?: string;
    /**
     * The label of the link
     */
    linkLabel?: string;
    /**
     * Determines href of the link
     */
    linkHref?: string;
    /**
     * Determines the router href
     */
    routerHref?: string;
    /**
     * Determines whether the link is inline or not
     */
    inlineLink?: boolean;
    /**
     * Determines in which tag the link should open.
     */
    linkTarget?: UiBasicNavigationTarget;
    /**
     * The message that the toast is delivering
     */
    message?: string;
    /**
     * The message shown after the link
     */
    messageAfterLink?: string;
    /**
     * The label of the primary action button
     */
    primaryActionLabel?: string;
    /**
     * The label of the secondary action button
     */
    secondaryActionLabel?: string;
    /**
     * Determines the {@link UiToastType type} of the toast message
     */
    type?: UiToastType;
    /**
     * Determines if the toast is automatically dismissible or not
     */
    autoDismissible?: boolean;
    /**
     *  Determines the delay of the automatic dismissal (in milliseconds)
     */
    autoDismissDelay?: number;
    /**
     * Determines the code to be executed when primary action button gets triggered
     */
    primaryActionCallback?: () => void;
    /**
     * Determines the code to be executed when secondary action button gets triggered
     */
    secondaryActionCallback?: () => void;
    /**
     * Determines the code to be executed when close button action gets triggered
     */
    closeActionCallback?: () => void;
    /**
     * Determines the code to be executed when link action gets triggered
     */
    linkActionCallback?: (linkClicked?: UiToastLinkClickedModel) => void;
    /**
     * {@link ToastMessageAdditionalData Additional data} of the toast
     */
    additionalData?: ToastMessageAdditionalData;
}
export interface UiToastLinkClickedModel {
    /**
     * Event that is being emitted
     */
    event: Event;
    /**
     * ID of the toast
     */
    id: string;
}
//# sourceMappingURL=ui-toast.model.d.ts.map