import { AfterViewInit, EventEmitter } from '@angular/core';
import { NgFormControlDirective } from '../ui-form-control/ui-ng-form-control.directive';
import { ValidationErrors } from '@angular/forms';
import { SieIconRegistryService } from '@siemens/icons';
import { BehaviorSubject } from 'rxjs';
import * as i0 from "@angular/core";
/**
 * # Toggle button component
 *
 * Toggle buttons are used to display the checked and unchecked state of a button.
 * They are part of a form, allowing us to select or deselect a given option.
 *
 * ## Component variations
 *
 * - Toggle button only
 * - Toggle button with a label to the right (when `labelChecked` value is defined)
 * - Toggle button with a label to the left (when `labelUnchecked` value is defined)
 * - Toggle button with two labels (when both `labelUnchecked` and `labelChecked` values are defined)
 * - Toggle button with tooltip (when `tooltipChecked` or/and `tooltipUnchecked` values are defined)
 * - Toggle button with input hint (when `hint` value is defined)
 * - Disabled toggle button
 *
 * ## Content
 *
 * The toggle button component does not accept any content.
 *
 * ## Code example
 * @example ```html
 * <sie-ui-toggle-button id="toggleId" name="toggleName" labelUnchecked="Off" labelChecked="On"></sie-ui-toggle-button>
 * ```
 */
export declare class UiToggleButtonComponent extends NgFormControlDirective implements AfterViewInit {
    readonly iconReg: SieIconRegistryService;
    /**
     * Defines the label on the left side of the toggle button.
     */
    labelUnchecked: string;
    /**
     * Defines the label on the right side of the toggle button.
     */
    labelChecked: string;
    /**
     * Defines the tooltip text when the toggle button is checked.
     */
    tooltipChecked: string;
    /**
     * Defines the tooltip text when the toggle button is unchecked.
     */
    tooltipUnchecked: string;
    /**
     * Event triggered when the toggle button is clicked.
     */
    valueChange: EventEmitter<boolean>;
    /**
     * @param value Defines the value of the toggle button (used instead of checked)
     * @default false
     */
    set value(value: boolean);
    get value(): boolean;
    private _value;
    /** @ignore */
    readonly preloading$: BehaviorSubject<boolean>;
    constructor(iconReg: SieIconRegistryService);
    /** @ignore */
    ngAfterViewInit(): void;
    /** @ignore */
    onCheck(toggleState: boolean): void;
    /** @ignore */
    validateInternal(): ValidationErrors | null;
    /** @ignore */
    writeValue(checked: boolean): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiToggleButtonComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiToggleButtonComponent, "sie-ui-toggle-button", never, { "labelUnchecked": { "alias": "labelUnchecked"; "required": false; }; "labelChecked": { "alias": "labelChecked"; "required": false; }; "tooltipChecked": { "alias": "tooltipChecked"; "required": false; }; "tooltipUnchecked": { "alias": "tooltipUnchecked"; "required": false; }; "value": { "alias": "value"; "required": false; }; }, { "valueChange": "valueChange"; }, never, never, false, never>;
}
//# sourceMappingURL=ui-toggle-button.component.d.ts.map