import { ChangeDetectorRef, ElementRef, EventEmitter } from '@angular/core';
import { SieIconRegistryService } from '@siemens/icons';
import { UiTreeNavigationModel } from './ui-tree-navigation.model';
import * as i0 from "@angular/core";
export declare class UiTreeNavigationComponent {
    readonly iconReg: SieIconRegistryService;
    readonly hostElement: ElementRef;
    private readonly cdr;
    /**
     * Indicates that the tree is loading and skeletons are shown
     * @default false
     */
    treeLoading: boolean;
    /**
     * Defines whether node labels should be truncated or not
     * @default true
     */
    truncateLabels: boolean;
    /** @ignore internal use only */
    root: boolean;
    /**
     * List of nodes the tree displays
     */
    treeItems: UiTreeNavigationModel[];
    /** @ignore use native function for setting selected id instead */
    selectedNodeId: number;
    /** @ignore internal use only */
    hierarchyLevel: number;
    /**
     * Emits when an expandable node gets expanded
     */
    itemExpanded: EventEmitter<UiTreeNavigationModel>;
    /**
     * Emits when an interactable node gets selected
     */
    itemSelected: EventEmitter<UiTreeNavigationModel>;
    constructor(iconReg: SieIconRegistryService, hostElement: ElementRef, cdr: ChangeDetectorRef);
    /** @ignore */
    onItemExpanded(nestedListItem: UiTreeNavigationModel): void;
    /** @ignore */
    onItemSelectionChanged(treeItem: UiTreeNavigationModel): void;
    /**
     * Allows tree navigation web component to be reloaded from outside component
     */
    reloadComponent(): void;
    /**
     * Allows setting a selected node id, making the node bold and expanding the parent nodes
     * @param nodeId to be selected
     */
    selectNode(nodeId: number, treeItems?: UiTreeNavigationModel[]): void;
    private expandTree;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiTreeNavigationComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiTreeNavigationComponent, "sie-ui-tree-navigation", never, { "treeLoading": { "alias": "treeLoading"; "required": false; }; "truncateLabels": { "alias": "truncateLabels"; "required": false; }; "root": { "alias": "root"; "required": false; }; "treeItems": { "alias": "treeItems"; "required": false; }; "selectedNodeId": { "alias": "selectedNodeId"; "required": false; }; "hierarchyLevel": { "alias": "hierarchyLevel"; "required": false; }; }, { "itemExpanded": "itemExpanded"; "itemSelected": "itemSelected"; }, never, never, false, never>;
    static ngAcceptInputType_treeLoading: unknown;
    static ngAcceptInputType_truncateLabels: unknown;
}
//# sourceMappingURL=ui-tree-navigation.component.d.ts.map