import { AfterViewInit, ChangeDetectorRef, ElementRef, OnChanges, OnInit, Renderer2, SimpleChanges } from '@angular/core';
import { VideoPlayerRatio, VideoPlayerSize } from './ui-video-player.types';
import { UiVideoPlayerModel } from './ui-video-player.model';
import { SieIconRegistryService } from '@siemens/icons';
import { ScriptService } from '@siemens/core';
import * as i0 from "@angular/core";
/**
 * # Video Player component
 *
 * Videos are used as a part of a content item’s representation (functional),
 * e.g. showing product videos, etc. or part of the brand expression (emotional).
 *
 * ## Component variations
 *
 * This component has no variation. However, this component can be used in combination with the `ui-video-modal`.
 *
 * ## Content
 *
 * The video component does not accept any content.
 *
 * ## Code example
 * @example ```html
 * <sie-ui-video-player
 *   [ratio]="''16-9''"
 *    [size]="'l'"
 *    [video]="{
 *      videoId: '6106650258001',
 *      accountId: '1813624294001',
 *      playerId: 'VMi7Ptd8P',
 *      url: 'https://players.brightcove.net/1813624294001/VMi7Ptd8P_default/index.min.js'
 *     }"
 *    [autoplay]="'true'"
 *    [inModal]="true"
 * ></sie-ui-video-player>
 * ```
 */
export declare class UiVideoPlayerComponent implements OnInit, AfterViewInit, OnChanges {
    private readonly document;
    private readonly renderer;
    readonly iconReg: SieIconRegistryService;
    private readonly cdr;
    private readonly scriptService;
    /** @ignore */
    videoWrapper: ElementRef;
    /**
     * The {@link UiVideoPlayerModel video meta data}
     */
    video: UiVideoPlayerModel;
    /**
     * {@link VideoPlayerSize Size} of the video canvas
     * @default 'l'
     */
    size: VideoPlayerSize;
    /**
     * {@link VideoPlayerRatio Ratio} of the video canvas
     * @default '16-9'
     */
    ratio: VideoPlayerRatio;
    /**
     * @param value Defines if the video should start immediately
     * @default false
     */
    set autoplay(value: boolean);
    get autoplay(): boolean;
    /**
     * @param value Defines if the video is placed inside of an `ui-video-modal` component
     * @default false
     */
    set inModal(value: boolean);
    get inModal(): boolean;
    private _autoplay;
    private _inModal;
    private videoPlayer;
    /** @ignore */
    videoEl: HTMLElement;
    /** @ignore */
    placeholderImage: string;
    /** @ignore */
    showPlaceholder: boolean;
    constructor(document: Document, renderer: Renderer2, iconReg: SieIconRegistryService, cdr: ChangeDetectorRef, scriptService: ScriptService);
    /** @ignore */
    ngOnChanges(changes: SimpleChanges): Promise<void>;
    /** @ignore */
    ngAfterViewInit(): Promise<void>;
    private setVideoData;
    private videoScriptLoaded;
    /** @ignore */
    ngOnInit(): void;
    /**
     * Method that sets the placeholder image
     */
    setPlaceholderImage(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UiVideoPlayerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<UiVideoPlayerComponent, "sie-ui-video-player", never, { "video": { "alias": "video"; "required": false; }; "size": { "alias": "size"; "required": false; }; "ratio": { "alias": "ratio"; "required": false; }; "autoplay": { "alias": "autoplay"; "required": false; }; "inModal": { "alias": "inModal"; "required": false; }; }, {}, never, never, false, never>;
}
//# sourceMappingURL=ui-video-player.component.d.ts.map